/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Intrinsic Function Source Fragment                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_IR_INTRINSIC_AMDGCN_ENUMS_H
#define LLVM_IR_INTRINSIC_AMDGCN_ENUMS_H
namespace llvm::Intrinsic {
enum AMDGCNIntrinsics : unsigned {
// Enum values for intrinsics.
    amdgcn_add_max_i32 = 2226,                        // llvm.amdgcn.add.max.i32 (IntrinsicsAMDGPU.td:3761)
    amdgcn_add_max_u32,                        // llvm.amdgcn.add.max.u32 (IntrinsicsAMDGPU.td:3762)
    amdgcn_add_min_i32,                        // llvm.amdgcn.add.min.i32 (IntrinsicsAMDGPU.td:3763)
    amdgcn_add_min_u32,                        // llvm.amdgcn.add.min.u32 (IntrinsicsAMDGPU.td:3764)
    amdgcn_addrspacecast_nonnull,              // llvm.amdgcn.addrspacecast.nonnull (IntrinsicsAMDGPU.td:4229)
    amdgcn_alignbyte,                          // llvm.amdgcn.alignbyte (IntrinsicsAMDGPU.td:2484)
    amdgcn_ashr_pk_i8_i32,                     // llvm.amdgcn.ashr.pk.i8.i32 (IntrinsicsAMDGPU.td:3655)
    amdgcn_ashr_pk_u8_i32,                     // llvm.amdgcn.ashr.pk.u8.i32 (IntrinsicsAMDGPU.td:3659)
    amdgcn_ballot,                             // llvm.amdgcn.ballot (IntrinsicsAMDGPU.td:2415)
    amdgcn_bitop3,                             // llvm.amdgcn.bitop3 (IntrinsicsAMDGPU.td:885)
    amdgcn_buffer_wbinvl1,                     // llvm.amdgcn.buffer.wbinvl1 (IntrinsicsAMDGPU.td:2128)
    amdgcn_buffer_wbinvl1_sc,                  // llvm.amdgcn.buffer.wbinvl1.sc (IntrinsicsAMDGPU.td:2124)
    amdgcn_buffer_wbinvl1_vol,                 // llvm.amdgcn.buffer.wbinvl1.vol (IntrinsicsAMDGPU.td:2705)
    amdgcn_call_whole_wave,                    // llvm.amdgcn.call.whole.wave (IntrinsicsAMDGPU.td:2681)
    amdgcn_class,                              // llvm.amdgcn.class (IntrinsicsAMDGPU.td:531)
    amdgcn_cluster_id_x,                       // llvm.amdgcn.cluster.id.x (IntrinsicsAMDGPU.td:53)
    amdgcn_cluster_id_y,                       // llvm.amdgcn.cluster.id.y (IntrinsicsAMDGPU.td:55)
    amdgcn_cluster_id_z,                       // llvm.amdgcn.cluster.id.z (IntrinsicsAMDGPU.td:57)
    amdgcn_cluster_load_async_to_lds_b128,     // llvm.amdgcn.cluster.load.async.to.lds.b128 (IntrinsicsAMDGPU.td:3893)
    amdgcn_cluster_load_async_to_lds_b32,      // llvm.amdgcn.cluster.load.async.to.lds.b32 (IntrinsicsAMDGPU.td:3889)
    amdgcn_cluster_load_async_to_lds_b64,      // llvm.amdgcn.cluster.load.async.to.lds.b64 (IntrinsicsAMDGPU.td:3891)
    amdgcn_cluster_load_async_to_lds_b8,       // llvm.amdgcn.cluster.load.async.to.lds.b8 (IntrinsicsAMDGPU.td:3887)
    amdgcn_cluster_load_b128,                  // llvm.amdgcn.cluster.load.b128 (IntrinsicsAMDGPU.td:4205)
    amdgcn_cluster_load_b32,                   // llvm.amdgcn.cluster.load.b32 (IntrinsicsAMDGPU.td:4203)
    amdgcn_cluster_load_b64,                   // llvm.amdgcn.cluster.load.b64 (IntrinsicsAMDGPU.td:4204)
    amdgcn_cluster_workgroup_flat_id,          // llvm.amdgcn.cluster.workgroup.flat.id (IntrinsicsAMDGPU.td:172)
    amdgcn_cluster_workgroup_id_x,             // llvm.amdgcn.cluster.workgroup.id.x (IntrinsicsAMDGPU.td:53)
    amdgcn_cluster_workgroup_id_y,             // llvm.amdgcn.cluster.workgroup.id.y (IntrinsicsAMDGPU.td:55)
    amdgcn_cluster_workgroup_id_z,             // llvm.amdgcn.cluster.workgroup.id.z (IntrinsicsAMDGPU.td:57)
    amdgcn_cluster_workgroup_max_flat_id,      // llvm.amdgcn.cluster.workgroup.max.flat.id (IntrinsicsAMDGPU.td:177)
    amdgcn_cluster_workgroup_max_id_x,         // llvm.amdgcn.cluster.workgroup.max.id.x (IntrinsicsAMDGPU.td:53)
    amdgcn_cluster_workgroup_max_id_y,         // llvm.amdgcn.cluster.workgroup.max.id.y (IntrinsicsAMDGPU.td:55)
    amdgcn_cluster_workgroup_max_id_z,         // llvm.amdgcn.cluster.workgroup.max.id.z (IntrinsicsAMDGPU.td:57)
    amdgcn_cooperative_atomic_load_16x8B,      // llvm.amdgcn.cooperative.atomic.load.16x8B (IntrinsicsAMDGPU.td:3797)
    amdgcn_cooperative_atomic_load_32x4B,      // llvm.amdgcn.cooperative.atomic.load.32x4B (IntrinsicsAMDGPU.td:3795)
    amdgcn_cooperative_atomic_load_8x16B,      // llvm.amdgcn.cooperative.atomic.load.8x16B (IntrinsicsAMDGPU.td:3799)
    amdgcn_cooperative_atomic_store_16x8B,     // llvm.amdgcn.cooperative.atomic.store.16x8B (IntrinsicsAMDGPU.td:3798)
    amdgcn_cooperative_atomic_store_32x4B,     // llvm.amdgcn.cooperative.atomic.store.32x4B (IntrinsicsAMDGPU.td:3796)
    amdgcn_cooperative_atomic_store_8x16B,     // llvm.amdgcn.cooperative.atomic.store.8x16B (IntrinsicsAMDGPU.td:3800)
    amdgcn_cos,                                // llvm.amdgcn.cos (IntrinsicsAMDGPU.td:426)
    amdgcn_cs_chain,                           // llvm.amdgcn.cs.chain (IntrinsicsAMDGPU.td:2660)
    amdgcn_cubeid,                             // llvm.amdgcn.cubeid (IntrinsicsAMDGPU.td:540)
    amdgcn_cubema,                             // llvm.amdgcn.cubema (IntrinsicsAMDGPU.td:545)
    amdgcn_cubesc,                             // llvm.amdgcn.cubesc (IntrinsicsAMDGPU.td:550)
    amdgcn_cubetc,                             // llvm.amdgcn.cubetc (IntrinsicsAMDGPU.td:555)
    amdgcn_cvt_f16_bf8,                        // llvm.amdgcn.cvt.f16.bf8 (IntrinsicsAMDGPU.td:3707)
    amdgcn_cvt_f16_fp8,                        // llvm.amdgcn.cvt.f16.fp8 (IntrinsicsAMDGPU.td:3701)
    amdgcn_cvt_f32_bf8,                        // llvm.amdgcn.cvt.f32.bf8 (IntrinsicsAMDGPU.td:3538)
    amdgcn_cvt_f32_fp8,                        // llvm.amdgcn.cvt.f32.fp8 (IntrinsicsAMDGPU.td:3544)
    amdgcn_cvt_f32_fp8_e5m3,                   // llvm.amdgcn.cvt.f32.fp8.e5m3 (IntrinsicsAMDGPU.td:3550)
    amdgcn_cvt_off_f32_i4,                     // llvm.amdgcn.cvt.off.f32.i4 (IntrinsicsAMDGPU.td:3607)
    amdgcn_cvt_pk_bf8_f16,                     // llvm.amdgcn.cvt.pk.bf8.f16 (IntrinsicsAMDGPU.td:596)
    amdgcn_cvt_pk_bf8_f32,                     // llvm.amdgcn.cvt.pk.bf8.f32 (IntrinsicsAMDGPU.td:3570)
    amdgcn_cvt_pk_f16_bf8,                     // llvm.amdgcn.cvt.pk.f16.bf8 (IntrinsicsAMDGPU.td:588)
    amdgcn_cvt_pk_f16_fp8,                     // llvm.amdgcn.cvt.pk.f16.fp8 (IntrinsicsAMDGPU.td:584)
    amdgcn_cvt_pk_f32_bf8,                     // llvm.amdgcn.cvt.pk.f32.bf8 (IntrinsicsAMDGPU.td:3557)
    amdgcn_cvt_pk_f32_fp8,                     // llvm.amdgcn.cvt.pk.f32.fp8 (IntrinsicsAMDGPU.td:3563)
    amdgcn_cvt_pk_fp8_f16,                     // llvm.amdgcn.cvt.pk.fp8.f16 (IntrinsicsAMDGPU.td:592)
    amdgcn_cvt_pk_fp8_f32,                     // llvm.amdgcn.cvt.pk.fp8.f32 (IntrinsicsAMDGPU.td:3576)
    amdgcn_cvt_pk_fp8_f32_e5m3,                // llvm.amdgcn.cvt.pk.fp8.f32.e5m3 (IntrinsicsAMDGPU.td:3582)
    amdgcn_cvt_pk_i16,                         // llvm.amdgcn.cvt.pk.i16 (IntrinsicsAMDGPU.td:521)
    amdgcn_cvt_pk_u16,                         // llvm.amdgcn.cvt.pk.u16 (IntrinsicsAMDGPU.td:527)
    amdgcn_cvt_pk_u8_f32,                      // llvm.amdgcn.cvt.pk.u8.f32 (IntrinsicsAMDGPU.td:2399)
    amdgcn_cvt_pknorm_i16,                     // llvm.amdgcn.cvt.pknorm.i16 (IntrinsicsAMDGPU.td:511)
    amdgcn_cvt_pknorm_u16,                     // llvm.amdgcn.cvt.pknorm.u16 (IntrinsicsAMDGPU.td:516)
    amdgcn_cvt_pkrtz,                          // llvm.amdgcn.cvt.pkrtz (IntrinsicsAMDGPU.td:507)
    amdgcn_cvt_scale_pk16_bf16_bf6,            // llvm.amdgcn.cvt.scale.pk16.bf16.bf6 (IntrinsicsAMDGPU.td:678)
    amdgcn_cvt_scale_pk16_bf16_fp6,            // llvm.amdgcn.cvt.scale.pk16.bf16.fp6 (IntrinsicsAMDGPU.td:680)
    amdgcn_cvt_scale_pk16_f16_bf6,             // llvm.amdgcn.cvt.scale.pk16.f16.bf6 (IntrinsicsAMDGPU.td:677)
    amdgcn_cvt_scale_pk16_f16_fp6,             // llvm.amdgcn.cvt.scale.pk16.f16.fp6 (IntrinsicsAMDGPU.td:679)
    amdgcn_cvt_scale_pk16_f32_bf6,             // llvm.amdgcn.cvt.scale.pk16.f32.bf6 (IntrinsicsAMDGPU.td:682)
    amdgcn_cvt_scale_pk16_f32_fp6,             // llvm.amdgcn.cvt.scale.pk16.f32.fp6 (IntrinsicsAMDGPU.td:681)
    amdgcn_cvt_scale_pk8_bf16_bf8,             // llvm.amdgcn.cvt.scale.pk8.bf16.bf8 (IntrinsicsAMDGPU.td:671)
    amdgcn_cvt_scale_pk8_bf16_fp4,             // llvm.amdgcn.cvt.scale.pk8.bf16.fp4 (IntrinsicsAMDGPU.td:673)
    amdgcn_cvt_scale_pk8_bf16_fp8,             // llvm.amdgcn.cvt.scale.pk8.bf16.fp8 (IntrinsicsAMDGPU.td:669)
    amdgcn_cvt_scale_pk8_f16_bf8,              // llvm.amdgcn.cvt.scale.pk8.f16.bf8 (IntrinsicsAMDGPU.td:670)
    amdgcn_cvt_scale_pk8_f16_fp4,              // llvm.amdgcn.cvt.scale.pk8.f16.fp4 (IntrinsicsAMDGPU.td:672)
    amdgcn_cvt_scale_pk8_f16_fp8,              // llvm.amdgcn.cvt.scale.pk8.f16.fp8 (IntrinsicsAMDGPU.td:668)
    amdgcn_cvt_scale_pk8_f32_bf8,              // llvm.amdgcn.cvt.scale.pk8.f32.bf8 (IntrinsicsAMDGPU.td:675)
    amdgcn_cvt_scale_pk8_f32_fp4,              // llvm.amdgcn.cvt.scale.pk8.f32.fp4 (IntrinsicsAMDGPU.td:676)
    amdgcn_cvt_scale_pk8_f32_fp8,              // llvm.amdgcn.cvt.scale.pk8.f32.fp8 (IntrinsicsAMDGPU.td:674)
    amdgcn_cvt_scalef32_2xpk16_bf6_f32,        // llvm.amdgcn.cvt.scalef32.2xpk16.bf6.f32 (IntrinsicsAMDGPU.td:731)
    amdgcn_cvt_scalef32_2xpk16_fp6_f32,        // llvm.amdgcn.cvt.scalef32.2xpk16.fp6.f32 (IntrinsicsAMDGPU.td:730)
    amdgcn_cvt_scalef32_f16_bf8,               // llvm.amdgcn.cvt.scalef32.f16.bf8 (IntrinsicsAMDGPU.td:821)
    amdgcn_cvt_scalef32_f16_fp8,               // llvm.amdgcn.cvt.scalef32.f16.fp8 (IntrinsicsAMDGPU.td:820)
    amdgcn_cvt_scalef32_f32_bf8,               // llvm.amdgcn.cvt.scalef32.f32.bf8 (IntrinsicsAMDGPU.td:825)
    amdgcn_cvt_scalef32_f32_fp8,               // llvm.amdgcn.cvt.scalef32.f32.fp8 (IntrinsicsAMDGPU.td:824)
    amdgcn_cvt_scalef32_pk_bf16_bf8,           // llvm.amdgcn.cvt.scalef32.pk.bf16.bf8 (IntrinsicsAMDGPU.td:863)
    amdgcn_cvt_scalef32_pk_bf16_fp4,           // llvm.amdgcn.cvt.scalef32.pk.bf16.fp4 (IntrinsicsAMDGPU.td:849)
    amdgcn_cvt_scalef32_pk_bf16_fp8,           // llvm.amdgcn.cvt.scalef32.pk.bf16.fp8 (IntrinsicsAMDGPU.td:865)
    amdgcn_cvt_scalef32_pk_bf8_bf16,           // llvm.amdgcn.cvt.scalef32.pk.bf8.bf16 (IntrinsicsAMDGPU.td:839)
    amdgcn_cvt_scalef32_pk_bf8_f16,            // llvm.amdgcn.cvt.scalef32.pk.bf8.f16 (IntrinsicsAMDGPU.td:838)
    amdgcn_cvt_scalef32_pk_bf8_f32,            // llvm.amdgcn.cvt.scalef32.pk.bf8.f32 (IntrinsicsAMDGPU.td:829)
    amdgcn_cvt_scalef32_pk_f16_bf8,            // llvm.amdgcn.cvt.scalef32.pk.f16.bf8 (IntrinsicsAMDGPU.td:862)
    amdgcn_cvt_scalef32_pk_f16_fp4,            // llvm.amdgcn.cvt.scalef32.pk.f16.fp4 (IntrinsicsAMDGPU.td:848)
    amdgcn_cvt_scalef32_pk_f16_fp8,            // llvm.amdgcn.cvt.scalef32.pk.f16.fp8 (IntrinsicsAMDGPU.td:864)
    amdgcn_cvt_scalef32_pk_f32_bf8,            // llvm.amdgcn.cvt.scalef32.pk.f32.bf8 (IntrinsicsAMDGPU.td:833)
    amdgcn_cvt_scalef32_pk_f32_fp4,            // llvm.amdgcn.cvt.scalef32.pk.f32.fp4 (IntrinsicsAMDGPU.td:842)
    amdgcn_cvt_scalef32_pk_f32_fp8,            // llvm.amdgcn.cvt.scalef32.pk.f32.fp8 (IntrinsicsAMDGPU.td:832)
    amdgcn_cvt_scalef32_pk_fp4_bf16,           // llvm.amdgcn.cvt.scalef32.pk.fp4.bf16 (IntrinsicsAMDGPU.td:869)
    amdgcn_cvt_scalef32_pk_fp4_f16,            // llvm.amdgcn.cvt.scalef32.pk.fp4.f16 (IntrinsicsAMDGPU.td:868)
    amdgcn_cvt_scalef32_pk_fp4_f32,            // llvm.amdgcn.cvt.scalef32.pk.fp4.f32 (IntrinsicsAMDGPU.td:845)
    amdgcn_cvt_scalef32_pk_fp8_bf16,           // llvm.amdgcn.cvt.scalef32.pk.fp8.bf16 (IntrinsicsAMDGPU.td:837)
    amdgcn_cvt_scalef32_pk_fp8_f16,            // llvm.amdgcn.cvt.scalef32.pk.fp8.f16 (IntrinsicsAMDGPU.td:836)
    amdgcn_cvt_scalef32_pk_fp8_f32,            // llvm.amdgcn.cvt.scalef32.pk.fp8.f32 (IntrinsicsAMDGPU.td:828)
    amdgcn_cvt_scalef32_pk16_bf6_bf16,         // llvm.amdgcn.cvt.scalef32.pk16.bf6.bf16 (IntrinsicsAMDGPU.td:706)
    amdgcn_cvt_scalef32_pk16_bf6_f16,          // llvm.amdgcn.cvt.scalef32.pk16.bf6.f16 (IntrinsicsAMDGPU.td:704)
    amdgcn_cvt_scalef32_pk16_bf6_f32,          // llvm.amdgcn.cvt.scalef32.pk16.bf6.f32 (IntrinsicsAMDGPU.td:702)
    amdgcn_cvt_scalef32_pk16_fp6_bf16,         // llvm.amdgcn.cvt.scalef32.pk16.fp6.bf16 (IntrinsicsAMDGPU.td:705)
    amdgcn_cvt_scalef32_pk16_fp6_f16,          // llvm.amdgcn.cvt.scalef32.pk16.fp6.f16 (IntrinsicsAMDGPU.td:703)
    amdgcn_cvt_scalef32_pk16_fp6_f32,          // llvm.amdgcn.cvt.scalef32.pk16.fp6.f32 (IntrinsicsAMDGPU.td:701)
    amdgcn_cvt_scalef32_pk32_bf16_bf6,         // llvm.amdgcn.cvt.scalef32.pk32.bf16.bf6 (IntrinsicsAMDGPU.td:857)
    amdgcn_cvt_scalef32_pk32_bf16_fp6,         // llvm.amdgcn.cvt.scalef32.pk32.bf16.fp6 (IntrinsicsAMDGPU.td:859)
    amdgcn_cvt_scalef32_pk32_bf6_bf16,         // llvm.amdgcn.cvt.scalef32.pk32.bf6.bf16 (IntrinsicsAMDGPU.td:693)
    amdgcn_cvt_scalef32_pk32_bf6_f16,          // llvm.amdgcn.cvt.scalef32.pk32.bf6.f16 (IntrinsicsAMDGPU.td:689)
    amdgcn_cvt_scalef32_pk32_f16_bf6,          // llvm.amdgcn.cvt.scalef32.pk32.f16.bf6 (IntrinsicsAMDGPU.td:856)
    amdgcn_cvt_scalef32_pk32_f16_fp6,          // llvm.amdgcn.cvt.scalef32.pk32.f16.fp6 (IntrinsicsAMDGPU.td:858)
    amdgcn_cvt_scalef32_pk32_f32_bf6,          // llvm.amdgcn.cvt.scalef32.pk32.f32.bf6 (IntrinsicsAMDGPU.td:853)
    amdgcn_cvt_scalef32_pk32_f32_fp6,          // llvm.amdgcn.cvt.scalef32.pk32.f32.fp6 (IntrinsicsAMDGPU.td:852)
    amdgcn_cvt_scalef32_pk32_fp6_bf16,         // llvm.amdgcn.cvt.scalef32.pk32.fp6.bf16 (IntrinsicsAMDGPU.td:692)
    amdgcn_cvt_scalef32_pk32_fp6_f16,          // llvm.amdgcn.cvt.scalef32.pk32.fp6.f16 (IntrinsicsAMDGPU.td:688)
    amdgcn_cvt_scalef32_pk8_bf8_bf16,          // llvm.amdgcn.cvt.scalef32.pk8.bf8.bf16 (IntrinsicsAMDGPU.td:691)
    amdgcn_cvt_scalef32_pk8_bf8_f16,           // llvm.amdgcn.cvt.scalef32.pk8.bf8.f16 (IntrinsicsAMDGPU.td:695)
    amdgcn_cvt_scalef32_pk8_bf8_f32,           // llvm.amdgcn.cvt.scalef32.pk8.bf8.f32 (IntrinsicsAMDGPU.td:697)
    amdgcn_cvt_scalef32_pk8_fp4_bf16,          // llvm.amdgcn.cvt.scalef32.pk8.fp4.bf16 (IntrinsicsAMDGPU.td:700)
    amdgcn_cvt_scalef32_pk8_fp4_f16,           // llvm.amdgcn.cvt.scalef32.pk8.fp4.f16 (IntrinsicsAMDGPU.td:699)
    amdgcn_cvt_scalef32_pk8_fp4_f32,           // llvm.amdgcn.cvt.scalef32.pk8.fp4.f32 (IntrinsicsAMDGPU.td:698)
    amdgcn_cvt_scalef32_pk8_fp8_bf16,          // llvm.amdgcn.cvt.scalef32.pk8.fp8.bf16 (IntrinsicsAMDGPU.td:690)
    amdgcn_cvt_scalef32_pk8_fp8_f16,           // llvm.amdgcn.cvt.scalef32.pk8.fp8.f16 (IntrinsicsAMDGPU.td:694)
    amdgcn_cvt_scalef32_pk8_fp8_f32,           // llvm.amdgcn.cvt.scalef32.pk8.fp8.f32 (IntrinsicsAMDGPU.td:696)
    amdgcn_cvt_scalef32_sr_bf8_bf16,           // llvm.amdgcn.cvt.scalef32.sr.bf8.bf16 (IntrinsicsAMDGPU.td:874)
    amdgcn_cvt_scalef32_sr_bf8_f16,            // llvm.amdgcn.cvt.scalef32.sr.bf8.f16 (IntrinsicsAMDGPU.td:875)
    amdgcn_cvt_scalef32_sr_bf8_f32,            // llvm.amdgcn.cvt.scalef32.sr.bf8.f32 (IntrinsicsAMDGPU.td:876)
    amdgcn_cvt_scalef32_sr_fp8_bf16,           // llvm.amdgcn.cvt.scalef32.sr.fp8.bf16 (IntrinsicsAMDGPU.td:877)
    amdgcn_cvt_scalef32_sr_fp8_f16,            // llvm.amdgcn.cvt.scalef32.sr.fp8.f16 (IntrinsicsAMDGPU.td:878)
    amdgcn_cvt_scalef32_sr_fp8_f32,            // llvm.amdgcn.cvt.scalef32.sr.fp8.f32 (IntrinsicsAMDGPU.td:879)
    amdgcn_cvt_scalef32_sr_pk_fp4_bf16,        // llvm.amdgcn.cvt.scalef32.sr.pk.fp4.bf16 (IntrinsicsAMDGPU.td:872)
    amdgcn_cvt_scalef32_sr_pk_fp4_f16,         // llvm.amdgcn.cvt.scalef32.sr.pk.fp4.f16 (IntrinsicsAMDGPU.td:871)
    amdgcn_cvt_scalef32_sr_pk_fp4_f32,         // llvm.amdgcn.cvt.scalef32.sr.pk.fp4.f32 (IntrinsicsAMDGPU.td:873)
    amdgcn_cvt_scalef32_sr_pk16_bf6_bf16,      // llvm.amdgcn.cvt.scalef32.sr.pk16.bf6.bf16 (IntrinsicsAMDGPU.td:728)
    amdgcn_cvt_scalef32_sr_pk16_bf6_f16,       // llvm.amdgcn.cvt.scalef32.sr.pk16.bf6.f16 (IntrinsicsAMDGPU.td:726)
    amdgcn_cvt_scalef32_sr_pk16_bf6_f32,       // llvm.amdgcn.cvt.scalef32.sr.pk16.bf6.f32 (IntrinsicsAMDGPU.td:724)
    amdgcn_cvt_scalef32_sr_pk16_fp6_bf16,      // llvm.amdgcn.cvt.scalef32.sr.pk16.fp6.bf16 (IntrinsicsAMDGPU.td:727)
    amdgcn_cvt_scalef32_sr_pk16_fp6_f16,       // llvm.amdgcn.cvt.scalef32.sr.pk16.fp6.f16 (IntrinsicsAMDGPU.td:725)
    amdgcn_cvt_scalef32_sr_pk16_fp6_f32,       // llvm.amdgcn.cvt.scalef32.sr.pk16.fp6.f32 (IntrinsicsAMDGPU.td:723)
    amdgcn_cvt_scalef32_sr_pk32_bf6_bf16,      // llvm.amdgcn.cvt.scalef32.sr.pk32.bf6.bf16 (IntrinsicsAMDGPU.td:713)
    amdgcn_cvt_scalef32_sr_pk32_bf6_f16,       // llvm.amdgcn.cvt.scalef32.sr.pk32.bf6.f16 (IntrinsicsAMDGPU.td:711)
    amdgcn_cvt_scalef32_sr_pk32_bf6_f32,       // llvm.amdgcn.cvt.scalef32.sr.pk32.bf6.f32 (IntrinsicsAMDGPU.td:709)
    amdgcn_cvt_scalef32_sr_pk32_fp6_bf16,      // llvm.amdgcn.cvt.scalef32.sr.pk32.fp6.bf16 (IntrinsicsAMDGPU.td:712)
    amdgcn_cvt_scalef32_sr_pk32_fp6_f16,       // llvm.amdgcn.cvt.scalef32.sr.pk32.fp6.f16 (IntrinsicsAMDGPU.td:710)
    amdgcn_cvt_scalef32_sr_pk32_fp6_f32,       // llvm.amdgcn.cvt.scalef32.sr.pk32.fp6.f32 (IntrinsicsAMDGPU.td:708)
    amdgcn_cvt_scalef32_sr_pk8_bf8_bf16,       // llvm.amdgcn.cvt.scalef32.sr.pk8.bf8.bf16 (IntrinsicsAMDGPU.td:715)
    amdgcn_cvt_scalef32_sr_pk8_bf8_f16,        // llvm.amdgcn.cvt.scalef32.sr.pk8.bf8.f16 (IntrinsicsAMDGPU.td:717)
    amdgcn_cvt_scalef32_sr_pk8_bf8_f32,        // llvm.amdgcn.cvt.scalef32.sr.pk8.bf8.f32 (IntrinsicsAMDGPU.td:719)
    amdgcn_cvt_scalef32_sr_pk8_fp4_bf16,       // llvm.amdgcn.cvt.scalef32.sr.pk8.fp4.bf16 (IntrinsicsAMDGPU.td:722)
    amdgcn_cvt_scalef32_sr_pk8_fp4_f16,        // llvm.amdgcn.cvt.scalef32.sr.pk8.fp4.f16 (IntrinsicsAMDGPU.td:721)
    amdgcn_cvt_scalef32_sr_pk8_fp4_f32,        // llvm.amdgcn.cvt.scalef32.sr.pk8.fp4.f32 (IntrinsicsAMDGPU.td:720)
    amdgcn_cvt_scalef32_sr_pk8_fp8_bf16,       // llvm.amdgcn.cvt.scalef32.sr.pk8.fp8.bf16 (IntrinsicsAMDGPU.td:714)
    amdgcn_cvt_scalef32_sr_pk8_fp8_f16,        // llvm.amdgcn.cvt.scalef32.sr.pk8.fp8.f16 (IntrinsicsAMDGPU.td:716)
    amdgcn_cvt_scalef32_sr_pk8_fp8_f32,        // llvm.amdgcn.cvt.scalef32.sr.pk8.fp8.f32 (IntrinsicsAMDGPU.td:718)
    amdgcn_cvt_sr_bf16_f32,                    // llvm.amdgcn.cvt.sr.bf16.f32 (IntrinsicsAMDGPU.td:816)
    amdgcn_cvt_sr_bf8_f16,                     // llvm.amdgcn.cvt.sr.bf8.f16 (IntrinsicsAMDGPU.td:647)
    amdgcn_cvt_sr_bf8_f32,                     // llvm.amdgcn.cvt.sr.bf8.f32 (IntrinsicsAMDGPU.td:3589)
    amdgcn_cvt_sr_f16_f32,                     // llvm.amdgcn.cvt.sr.f16.f32 (IntrinsicsAMDGPU.td:817)
    amdgcn_cvt_sr_fp8_f16,                     // llvm.amdgcn.cvt.sr.fp8.f16 (IntrinsicsAMDGPU.td:640)
    amdgcn_cvt_sr_fp8_f32,                     // llvm.amdgcn.cvt.sr.fp8.f32 (IntrinsicsAMDGPU.td:3595)
    amdgcn_cvt_sr_fp8_f32_e5m3,                // llvm.amdgcn.cvt.sr.fp8.f32.e5m3 (IntrinsicsAMDGPU.td:3601)
    amdgcn_cvt_sr_pk_bf16_f32,                 // llvm.amdgcn.cvt.sr.pk.bf16.f32 (IntrinsicsAMDGPU.td:580)
    amdgcn_cvt_sr_pk_f16_f32,                  // llvm.amdgcn.cvt.sr.pk.f16.f32 (IntrinsicsAMDGPU.td:576)
    amdgcn_dead,                               // llvm.amdgcn.dead (IntrinsicsAMDGPU.td:4238)
    amdgcn_dispatch_id,                        // llvm.amdgcn.dispatch.id (IntrinsicsAMDGPU.td:207)
    amdgcn_dispatch_ptr,                       // llvm.amdgcn.dispatch.ptr (IntrinsicsAMDGPU.td:181)
    amdgcn_div_fixup,                          // llvm.amdgcn.div.fixup (IntrinsicsAMDGPU.td:414)
    amdgcn_div_fmas,                           // llvm.amdgcn.div.fmas (IntrinsicsAMDGPU.td:410)
    amdgcn_div_scale,                          // llvm.amdgcn.div.scale (IntrinsicsAMDGPU.td:400)
    amdgcn_dot4_f32_bf8_bf8,                   // llvm.amdgcn.dot4.f32.bf8.bf8 (IntrinsicsAMDGPU.td:3404)
    amdgcn_dot4_f32_bf8_fp8,                   // llvm.amdgcn.dot4.f32.bf8.fp8 (IntrinsicsAMDGPU.td:3402)
    amdgcn_dot4_f32_fp8_bf8,                   // llvm.amdgcn.dot4.f32.fp8.bf8 (IntrinsicsAMDGPU.td:3401)
    amdgcn_dot4_f32_fp8_fp8,                   // llvm.amdgcn.dot4.f32.fp8.fp8 (IntrinsicsAMDGPU.td:3403)
    amdgcn_ds_add_gs_reg_rtn,                  // llvm.amdgcn.ds.add.gs.reg.rtn (IntrinsicsAMDGPU.td:2880)
    amdgcn_ds_append,                          // llvm.amdgcn.ds.append (IntrinsicsAMDGPU.td:635)
    amdgcn_ds_atomic_async_barrier_arrive_b64,  // llvm.amdgcn.ds.atomic.async.barrier.arrive.b64 (IntrinsicsAMDGPU.td:3682)
    amdgcn_ds_atomic_barrier_arrive_rtn_b64,   // llvm.amdgcn.ds.atomic.barrier.arrive.rtn.b64 (IntrinsicsAMDGPU.td:3689)
    amdgcn_ds_bpermute,                        // llvm.amdgcn.ds.bpermute (IntrinsicsAMDGPU.td:2761)
    amdgcn_ds_bpermute_fi_b32,                 // llvm.amdgcn.ds.bpermute.fi.b32 (IntrinsicsAMDGPU.td:3154)
    amdgcn_ds_bvh_stack_push4_pop1_rtn,        // llvm.amdgcn.ds.bvh.stack.push4.pop1.rtn (IntrinsicsAMDGPU.td:2985)
    amdgcn_ds_bvh_stack_push8_pop1_rtn,        // llvm.amdgcn.ds.bvh.stack.push8.pop1.rtn (IntrinsicsAMDGPU.td:2988)
    amdgcn_ds_bvh_stack_push8_pop2_rtn,        // llvm.amdgcn.ds.bvh.stack.push8.pop2.rtn (IntrinsicsAMDGPU.td:2991)
    amdgcn_ds_bvh_stack_rtn,                   // llvm.amdgcn.ds.bvh.stack.rtn (IntrinsicsAMDGPU.td:2904)
    amdgcn_ds_consume,                         // llvm.amdgcn.ds.consume (IntrinsicsAMDGPU.td:636)
    amdgcn_ds_gws_barrier,                     // llvm.amdgcn.ds.gws.barrier (IntrinsicsAMDGPU.td:2523)
    amdgcn_ds_gws_init,                        // llvm.amdgcn.ds.gws.init (IntrinsicsAMDGPU.td:2511)
    amdgcn_ds_gws_sema_br,                     // llvm.amdgcn.ds.gws.sema.br (IntrinsicsAMDGPU.td:2541)
    amdgcn_ds_gws_sema_p,                      // llvm.amdgcn.ds.gws.sema.p (IntrinsicsAMDGPU.td:2550)
    amdgcn_ds_gws_sema_release_all,            // llvm.amdgcn.ds.gws.sema.release.all (IntrinsicsAMDGPU.td:2559)
    amdgcn_ds_gws_sema_v,                      // llvm.amdgcn.ds.gws.sema.v (IntrinsicsAMDGPU.td:2532)
    amdgcn_ds_load_tr16_b128,                  // llvm.amdgcn.ds.load.tr16.b128 (IntrinsicsAMDGPU.td:3133)
    amdgcn_ds_load_tr4_b64,                    // llvm.amdgcn.ds.load.tr4.b64 (IntrinsicsAMDGPU.td:3134)
    amdgcn_ds_load_tr6_b96,                    // llvm.amdgcn.ds.load.tr6.b96 (IntrinsicsAMDGPU.td:3135)
    amdgcn_ds_load_tr8_b64,                    // llvm.amdgcn.ds.load.tr8.b64 (IntrinsicsAMDGPU.td:3132)
    amdgcn_ds_ordered_add,                     // llvm.amdgcn.ds.ordered.add (IntrinsicsAMDGPU.td:631)
    amdgcn_ds_ordered_swap,                    // llvm.amdgcn.ds.ordered.swap (IntrinsicsAMDGPU.td:632)
    amdgcn_ds_permute,                         // llvm.amdgcn.ds.permute (IntrinsicsAMDGPU.td:2755)
    amdgcn_ds_read_tr16_b64,                   // llvm.amdgcn.ds.read.tr16.b64 (IntrinsicsAMDGPU.td:3139)
    amdgcn_ds_read_tr4_b64,                    // llvm.amdgcn.ds.read.tr4.b64 (IntrinsicsAMDGPU.td:3136)
    amdgcn_ds_read_tr6_b96,                    // llvm.amdgcn.ds.read.tr6.b96 (IntrinsicsAMDGPU.td:3137)
    amdgcn_ds_read_tr8_b64,                    // llvm.amdgcn.ds.read.tr8.b64 (IntrinsicsAMDGPU.td:3138)
    amdgcn_ds_sub_gs_reg_rtn,                  // llvm.amdgcn.ds.sub.gs.reg.rtn (IntrinsicsAMDGPU.td:2886)
    amdgcn_ds_swizzle,                         // llvm.amdgcn.ds.swizzle (IntrinsicsAMDGPU.td:2355)
    amdgcn_else,                               // llvm.amdgcn.else (IntrinsicsAMDGPU.td:3822)
    amdgcn_end_cf,                             // llvm.amdgcn.end.cf (IntrinsicsAMDGPU.td:3835)
    amdgcn_endpgm,                             // llvm.amdgcn.endpgm (IntrinsicsAMDGPU.td:2591)
    amdgcn_exp,                                // llvm.amdgcn.exp (IntrinsicsAMDGPU.td:2084)
    amdgcn_exp_compr,                          // llvm.amdgcn.exp.compr (IntrinsicsAMDGPU.td:2113)
    amdgcn_exp_row,                            // llvm.amdgcn.exp.row (IntrinsicsAMDGPU.td:2099)
    amdgcn_exp2,                               // llvm.amdgcn.exp2 (IntrinsicsAMDGPU.td:443)
    amdgcn_fcmp,                               // llvm.amdgcn.fcmp (IntrinsicsAMDGPU.td:2408)
    amdgcn_fdiv_fast,                          // llvm.amdgcn.fdiv.fast (IntrinsicsAMDGPU.td:3843)
    amdgcn_fdot2,                              // llvm.amdgcn.fdot2 (IntrinsicsAMDGPU.td:3183)
    amdgcn_fdot2_bf16_bf16,                    // llvm.amdgcn.fdot2.bf16.bf16 (IntrinsicsAMDGPU.td:3211)
    amdgcn_fdot2_f16_f16,                      // llvm.amdgcn.fdot2.f16.f16 (IntrinsicsAMDGPU.td:3198)
    amdgcn_fdot2_f32_bf16,                     // llvm.amdgcn.fdot2.f32.bf16 (IntrinsicsAMDGPU.td:3224)
    amdgcn_fdot2c_f32_bf16,                    // llvm.amdgcn.fdot2c.f32.bf16 (IntrinsicsAMDGPU.td:3242)
    amdgcn_flat_atomic_fmax_num,               // llvm.amdgcn.flat.atomic.fmax.num (IntrinsicsAMDGPU.td:3108)
    amdgcn_flat_atomic_fmin_num,               // llvm.amdgcn.flat.atomic.fmin.num (IntrinsicsAMDGPU.td:3107)
    amdgcn_flat_load_monitor_b128,             // llvm.amdgcn.flat.load.monitor.b128 (IntrinsicsAMDGPU.td:4222)
    amdgcn_flat_load_monitor_b32,              // llvm.amdgcn.flat.load.monitor.b32 (IntrinsicsAMDGPU.td:4220)
    amdgcn_flat_load_monitor_b64,              // llvm.amdgcn.flat.load.monitor.b64 (IntrinsicsAMDGPU.td:4221)
    amdgcn_flat_prefetch,                      // llvm.amdgcn.flat.prefetch (IntrinsicsAMDGPU.td:3159)
    amdgcn_fma_legacy,                         // llvm.amdgcn.fma.legacy (IntrinsicsAMDGPU.td:461)
    amdgcn_fmad_ftz,                           // llvm.amdgcn.fmad.ftz (IntrinsicsAMDGPU.td:567)
    amdgcn_fmed3,                              // llvm.amdgcn.fmed3 (IntrinsicsAMDGPU.td:535)
    amdgcn_fmul_legacy,                        // llvm.amdgcn.fmul.legacy (IntrinsicsAMDGPU.td:451)
    amdgcn_fract,                              // llvm.amdgcn.fract (IntrinsicsAMDGPU.td:503)
    amdgcn_frexp_exp,                          // llvm.amdgcn.frexp.exp (IntrinsicsAMDGPU.td:496)
    amdgcn_frexp_mant,                         // llvm.amdgcn.frexp.mant (IntrinsicsAMDGPU.td:492)
    amdgcn_global_atomic_fmax_num,             // llvm.amdgcn.global.atomic.fmax.num (IntrinsicsAMDGPU.td:3110)
    amdgcn_global_atomic_fmin_num,             // llvm.amdgcn.global.atomic.fmin.num (IntrinsicsAMDGPU.td:3109)
    amdgcn_global_atomic_ordered_add_b64,      // llvm.amdgcn.global.atomic.ordered.add.b64 (IntrinsicsAMDGPU.td:3105)
    amdgcn_global_load_async_to_lds_b128,      // llvm.amdgcn.global.load.async.to.lds.b128 (IntrinsicsAMDGPU.td:3902)
    amdgcn_global_load_async_to_lds_b32,       // llvm.amdgcn.global.load.async.to.lds.b32 (IntrinsicsAMDGPU.td:3898)
    amdgcn_global_load_async_to_lds_b64,       // llvm.amdgcn.global.load.async.to.lds.b64 (IntrinsicsAMDGPU.td:3900)
    amdgcn_global_load_async_to_lds_b8,        // llvm.amdgcn.global.load.async.to.lds.b8 (IntrinsicsAMDGPU.td:3896)
    amdgcn_global_load_lds,                    // llvm.amdgcn.global.load.lds (IntrinsicsAMDGPU.td:2816)
    amdgcn_global_load_monitor_b128,           // llvm.amdgcn.global.load.monitor.b128 (IntrinsicsAMDGPU.td:4225)
    amdgcn_global_load_monitor_b32,            // llvm.amdgcn.global.load.monitor.b32 (IntrinsicsAMDGPU.td:4223)
    amdgcn_global_load_monitor_b64,            // llvm.amdgcn.global.load.monitor.b64 (IntrinsicsAMDGPU.td:4224)
    amdgcn_global_load_tr_b128,                // llvm.amdgcn.global.load.tr.b128 (IntrinsicsAMDGPU.td:3129)
    amdgcn_global_load_tr_b64,                 // llvm.amdgcn.global.load.tr.b64 (IntrinsicsAMDGPU.td:3128)
    amdgcn_global_load_tr4_b64,                // llvm.amdgcn.global.load.tr4.b64 (IntrinsicsAMDGPU.td:3130)
    amdgcn_global_load_tr6_b96,                // llvm.amdgcn.global.load.tr6.b96 (IntrinsicsAMDGPU.td:3131)
    amdgcn_global_prefetch,                    // llvm.amdgcn.global.prefetch (IntrinsicsAMDGPU.td:3168)
    amdgcn_global_store_async_from_lds_b128,   // llvm.amdgcn.global.store.async.from.lds.b128 (IntrinsicsAMDGPU.td:3911)
    amdgcn_global_store_async_from_lds_b32,    // llvm.amdgcn.global.store.async.from.lds.b32 (IntrinsicsAMDGPU.td:3907)
    amdgcn_global_store_async_from_lds_b64,    // llvm.amdgcn.global.store.async.from.lds.b64 (IntrinsicsAMDGPU.td:3909)
    amdgcn_global_store_async_from_lds_b8,     // llvm.amdgcn.global.store.async.from.lds.b8 (IntrinsicsAMDGPU.td:3905)
    amdgcn_groupstaticsize,                    // llvm.amdgcn.groupstaticsize (IntrinsicsAMDGPU.td:203)
    amdgcn_icmp,                               // llvm.amdgcn.icmp (IntrinsicsAMDGPU.td:2403)
    amdgcn_if,                                 // llvm.amdgcn.if (IntrinsicsAMDGPU.td:3818)
    amdgcn_if_break,                           // llvm.amdgcn.if.break (IntrinsicsAMDGPU.td:3826)
    amdgcn_iglp_opt,                           // llvm.amdgcn.iglp.opt (IntrinsicsAMDGPU.td:382)
    amdgcn_image_atomic_add_1d,                // llvm.amdgcn.image.atomic.add.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_1darray,           // llvm.amdgcn.image.atomic.add.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_2d,                // llvm.amdgcn.image.atomic.add.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_2darray,           // llvm.amdgcn.image.atomic.add.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_2darraymsaa,       // llvm.amdgcn.image.atomic.add.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_2dmsaa,            // llvm.amdgcn.image.atomic.add.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_3d,                // llvm.amdgcn.image.atomic.add.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_cube,              // llvm.amdgcn.image.atomic.add.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_1d,            // llvm.amdgcn.image.atomic.add.flt.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_1darray,       // llvm.amdgcn.image.atomic.add.flt.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_2d,            // llvm.amdgcn.image.atomic.add.flt.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_2darray,       // llvm.amdgcn.image.atomic.add.flt.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_2darraymsaa,   // llvm.amdgcn.image.atomic.add.flt.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_2dmsaa,        // llvm.amdgcn.image.atomic.add.flt.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_3d,            // llvm.amdgcn.image.atomic.add.flt.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_add_flt_cube,          // llvm.amdgcn.image.atomic.add.flt.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_1d,                // llvm.amdgcn.image.atomic.and.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_1darray,           // llvm.amdgcn.image.atomic.and.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_2d,                // llvm.amdgcn.image.atomic.and.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_2darray,           // llvm.amdgcn.image.atomic.and.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_2darraymsaa,       // llvm.amdgcn.image.atomic.and.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_2dmsaa,            // llvm.amdgcn.image.atomic.and.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_3d,                // llvm.amdgcn.image.atomic.and.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_and_cube,              // llvm.amdgcn.image.atomic.and.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_1d,            // llvm.amdgcn.image.atomic.cmpswap.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_1darray,       // llvm.amdgcn.image.atomic.cmpswap.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_2d,            // llvm.amdgcn.image.atomic.cmpswap.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_2darray,       // llvm.amdgcn.image.atomic.cmpswap.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_2darraymsaa,   // llvm.amdgcn.image.atomic.cmpswap.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_2dmsaa,        // llvm.amdgcn.image.atomic.cmpswap.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_3d,            // llvm.amdgcn.image.atomic.cmpswap.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_cmpswap_cube,          // llvm.amdgcn.image.atomic.cmpswap.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_1d,                // llvm.amdgcn.image.atomic.dec.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_1darray,           // llvm.amdgcn.image.atomic.dec.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_2d,                // llvm.amdgcn.image.atomic.dec.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_2darray,           // llvm.amdgcn.image.atomic.dec.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_2darraymsaa,       // llvm.amdgcn.image.atomic.dec.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_2dmsaa,            // llvm.amdgcn.image.atomic.dec.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_3d,                // llvm.amdgcn.image.atomic.dec.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_dec_cube,              // llvm.amdgcn.image.atomic.dec.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_1d,               // llvm.amdgcn.image.atomic.fmax.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_1darray,          // llvm.amdgcn.image.atomic.fmax.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_2d,               // llvm.amdgcn.image.atomic.fmax.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_2darray,          // llvm.amdgcn.image.atomic.fmax.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_2darraymsaa,      // llvm.amdgcn.image.atomic.fmax.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_2dmsaa,           // llvm.amdgcn.image.atomic.fmax.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_3d,               // llvm.amdgcn.image.atomic.fmax.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmax_cube,             // llvm.amdgcn.image.atomic.fmax.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_1d,               // llvm.amdgcn.image.atomic.fmin.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_1darray,          // llvm.amdgcn.image.atomic.fmin.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_2d,               // llvm.amdgcn.image.atomic.fmin.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_2darray,          // llvm.amdgcn.image.atomic.fmin.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_2darraymsaa,      // llvm.amdgcn.image.atomic.fmin.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_2dmsaa,           // llvm.amdgcn.image.atomic.fmin.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_3d,               // llvm.amdgcn.image.atomic.fmin.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_fmin_cube,             // llvm.amdgcn.image.atomic.fmin.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_1d,                // llvm.amdgcn.image.atomic.inc.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_1darray,           // llvm.amdgcn.image.atomic.inc.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_2d,                // llvm.amdgcn.image.atomic.inc.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_2darray,           // llvm.amdgcn.image.atomic.inc.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_2darraymsaa,       // llvm.amdgcn.image.atomic.inc.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_2dmsaa,            // llvm.amdgcn.image.atomic.inc.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_3d,                // llvm.amdgcn.image.atomic.inc.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_inc_cube,              // llvm.amdgcn.image.atomic.inc.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_1d,            // llvm.amdgcn.image.atomic.max.flt.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_1darray,       // llvm.amdgcn.image.atomic.max.flt.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_2d,            // llvm.amdgcn.image.atomic.max.flt.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_2darray,       // llvm.amdgcn.image.atomic.max.flt.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_2darraymsaa,   // llvm.amdgcn.image.atomic.max.flt.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_2dmsaa,        // llvm.amdgcn.image.atomic.max.flt.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_3d,            // llvm.amdgcn.image.atomic.max.flt.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_max_flt_cube,          // llvm.amdgcn.image.atomic.max.flt.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_1d,            // llvm.amdgcn.image.atomic.min.flt.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_1darray,       // llvm.amdgcn.image.atomic.min.flt.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_2d,            // llvm.amdgcn.image.atomic.min.flt.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_2darray,       // llvm.amdgcn.image.atomic.min.flt.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_2darraymsaa,   // llvm.amdgcn.image.atomic.min.flt.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_2dmsaa,        // llvm.amdgcn.image.atomic.min.flt.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_3d,            // llvm.amdgcn.image.atomic.min.flt.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_min_flt_cube,          // llvm.amdgcn.image.atomic.min.flt.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_1d,                 // llvm.amdgcn.image.atomic.or.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_1darray,            // llvm.amdgcn.image.atomic.or.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_2d,                 // llvm.amdgcn.image.atomic.or.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_2darray,            // llvm.amdgcn.image.atomic.or.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_2darraymsaa,        // llvm.amdgcn.image.atomic.or.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_2dmsaa,             // llvm.amdgcn.image.atomic.or.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_3d,                 // llvm.amdgcn.image.atomic.or.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_or_cube,               // llvm.amdgcn.image.atomic.or.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_1d,        // llvm.amdgcn.image.atomic.pk.add.bf16.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_1darray,   // llvm.amdgcn.image.atomic.pk.add.bf16.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_2d,        // llvm.amdgcn.image.atomic.pk.add.bf16.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_2darray,   // llvm.amdgcn.image.atomic.pk.add.bf16.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_2darraymsaa,  // llvm.amdgcn.image.atomic.pk.add.bf16.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_2dmsaa,    // llvm.amdgcn.image.atomic.pk.add.bf16.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_3d,        // llvm.amdgcn.image.atomic.pk.add.bf16.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_bf16_cube,      // llvm.amdgcn.image.atomic.pk.add.bf16.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_1d,         // llvm.amdgcn.image.atomic.pk.add.f16.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_1darray,    // llvm.amdgcn.image.atomic.pk.add.f16.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_2d,         // llvm.amdgcn.image.atomic.pk.add.f16.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_2darray,    // llvm.amdgcn.image.atomic.pk.add.f16.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_2darraymsaa,  // llvm.amdgcn.image.atomic.pk.add.f16.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_2dmsaa,     // llvm.amdgcn.image.atomic.pk.add.f16.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_3d,         // llvm.amdgcn.image.atomic.pk.add.f16.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_pk_add_f16_cube,       // llvm.amdgcn.image.atomic.pk.add.f16.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_1d,               // llvm.amdgcn.image.atomic.smax.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_1darray,          // llvm.amdgcn.image.atomic.smax.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_2d,               // llvm.amdgcn.image.atomic.smax.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_2darray,          // llvm.amdgcn.image.atomic.smax.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_2darraymsaa,      // llvm.amdgcn.image.atomic.smax.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_2dmsaa,           // llvm.amdgcn.image.atomic.smax.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_3d,               // llvm.amdgcn.image.atomic.smax.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smax_cube,             // llvm.amdgcn.image.atomic.smax.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_1d,               // llvm.amdgcn.image.atomic.smin.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_1darray,          // llvm.amdgcn.image.atomic.smin.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_2d,               // llvm.amdgcn.image.atomic.smin.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_2darray,          // llvm.amdgcn.image.atomic.smin.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_2darraymsaa,      // llvm.amdgcn.image.atomic.smin.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_2dmsaa,           // llvm.amdgcn.image.atomic.smin.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_3d,               // llvm.amdgcn.image.atomic.smin.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_smin_cube,             // llvm.amdgcn.image.atomic.smin.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_1d,                // llvm.amdgcn.image.atomic.sub.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_1darray,           // llvm.amdgcn.image.atomic.sub.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_2d,                // llvm.amdgcn.image.atomic.sub.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_2darray,           // llvm.amdgcn.image.atomic.sub.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_2darraymsaa,       // llvm.amdgcn.image.atomic.sub.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_2dmsaa,            // llvm.amdgcn.image.atomic.sub.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_3d,                // llvm.amdgcn.image.atomic.sub.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_sub_cube,              // llvm.amdgcn.image.atomic.sub.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_1d,               // llvm.amdgcn.image.atomic.swap.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_1darray,          // llvm.amdgcn.image.atomic.swap.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_2d,               // llvm.amdgcn.image.atomic.swap.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_2darray,          // llvm.amdgcn.image.atomic.swap.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_2darraymsaa,      // llvm.amdgcn.image.atomic.swap.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_2dmsaa,           // llvm.amdgcn.image.atomic.swap.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_3d,               // llvm.amdgcn.image.atomic.swap.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_swap_cube,             // llvm.amdgcn.image.atomic.swap.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_1d,               // llvm.amdgcn.image.atomic.umax.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_1darray,          // llvm.amdgcn.image.atomic.umax.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_2d,               // llvm.amdgcn.image.atomic.umax.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_2darray,          // llvm.amdgcn.image.atomic.umax.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_2darraymsaa,      // llvm.amdgcn.image.atomic.umax.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_2dmsaa,           // llvm.amdgcn.image.atomic.umax.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_3d,               // llvm.amdgcn.image.atomic.umax.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umax_cube,             // llvm.amdgcn.image.atomic.umax.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_1d,               // llvm.amdgcn.image.atomic.umin.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_1darray,          // llvm.amdgcn.image.atomic.umin.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_2d,               // llvm.amdgcn.image.atomic.umin.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_2darray,          // llvm.amdgcn.image.atomic.umin.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_2darraymsaa,      // llvm.amdgcn.image.atomic.umin.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_2dmsaa,           // llvm.amdgcn.image.atomic.umin.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_3d,               // llvm.amdgcn.image.atomic.umin.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_umin_cube,             // llvm.amdgcn.image.atomic.umin.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_1d,                // llvm.amdgcn.image.atomic.xor.1d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_1darray,           // llvm.amdgcn.image.atomic.xor.1darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_2d,                // llvm.amdgcn.image.atomic.xor.2d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_2darray,           // llvm.amdgcn.image.atomic.xor.2darray (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_2darraymsaa,       // llvm.amdgcn.image.atomic.xor.2darraymsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_2dmsaa,            // llvm.amdgcn.image.atomic.xor.2dmsaa (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_3d,                // llvm.amdgcn.image.atomic.xor.3d (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_atomic_xor_cube,              // llvm.amdgcn.image.atomic.xor.cube (IntrinsicsAMDGPU.td:1355)
    amdgcn_image_bvh_dual_intersect_ray,       // llvm.amdgcn.image.bvh.dual.intersect.ray (IntrinsicsAMDGPU.td:2999)
    amdgcn_image_bvh_intersect_ray,            // llvm.amdgcn.image.bvh.intersect.ray (IntrinsicsAMDGPU.td:2865)
    amdgcn_image_bvh8_intersect_ray,           // llvm.amdgcn.image.bvh8.intersect.ray (IntrinsicsAMDGPU.td:3010)
    amdgcn_image_gather4_2d,                   // llvm.amdgcn.image.gather4.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_2darray,              // llvm.amdgcn.image.gather4.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_2d,                 // llvm.amdgcn.image.gather4.b.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_2darray,            // llvm.amdgcn.image.gather4.b.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_cl_2d,              // llvm.amdgcn.image.gather4.b.cl.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_cl_2darray,         // llvm.amdgcn.image.gather4.b.cl.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_cl_cube,            // llvm.amdgcn.image.gather4.b.cl.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_cl_o_2d,            // llvm.amdgcn.image.gather4.b.cl.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_cl_o_2darray,       // llvm.amdgcn.image.gather4.b.cl.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_cl_o_cube,          // llvm.amdgcn.image.gather4.b.cl.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_cube,               // llvm.amdgcn.image.gather4.b.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_o_2d,               // llvm.amdgcn.image.gather4.b.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_o_2darray,          // llvm.amdgcn.image.gather4.b.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_b_o_cube,             // llvm.amdgcn.image.gather4.b.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_2d,                 // llvm.amdgcn.image.gather4.c.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_2darray,            // llvm.amdgcn.image.gather4.c.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_2d,               // llvm.amdgcn.image.gather4.c.b.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_2darray,          // llvm.amdgcn.image.gather4.c.b.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_cl_2d,            // llvm.amdgcn.image.gather4.c.b.cl.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_cl_2darray,       // llvm.amdgcn.image.gather4.c.b.cl.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_cl_cube,          // llvm.amdgcn.image.gather4.c.b.cl.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_cl_o_2d,          // llvm.amdgcn.image.gather4.c.b.cl.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_cl_o_2darray,     // llvm.amdgcn.image.gather4.c.b.cl.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_cl_o_cube,        // llvm.amdgcn.image.gather4.c.b.cl.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_cube,             // llvm.amdgcn.image.gather4.c.b.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_o_2d,             // llvm.amdgcn.image.gather4.c.b.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_o_2darray,        // llvm.amdgcn.image.gather4.c.b.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_b_o_cube,           // llvm.amdgcn.image.gather4.c.b.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_cl_2d,              // llvm.amdgcn.image.gather4.c.cl.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_cl_2darray,         // llvm.amdgcn.image.gather4.c.cl.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_cl_cube,            // llvm.amdgcn.image.gather4.c.cl.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_cl_o_2d,            // llvm.amdgcn.image.gather4.c.cl.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_cl_o_2darray,       // llvm.amdgcn.image.gather4.c.cl.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_cl_o_cube,          // llvm.amdgcn.image.gather4.c.cl.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_cube,               // llvm.amdgcn.image.gather4.c.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_l_2d,               // llvm.amdgcn.image.gather4.c.l.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_l_2darray,          // llvm.amdgcn.image.gather4.c.l.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_l_cube,             // llvm.amdgcn.image.gather4.c.l.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_l_o_2d,             // llvm.amdgcn.image.gather4.c.l.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_l_o_2darray,        // llvm.amdgcn.image.gather4.c.l.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_l_o_cube,           // llvm.amdgcn.image.gather4.c.l.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_lz_2d,              // llvm.amdgcn.image.gather4.c.lz.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_lz_2darray,         // llvm.amdgcn.image.gather4.c.lz.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_lz_cube,            // llvm.amdgcn.image.gather4.c.lz.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_lz_o_2d,            // llvm.amdgcn.image.gather4.c.lz.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_lz_o_2darray,       // llvm.amdgcn.image.gather4.c.lz.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_lz_o_cube,          // llvm.amdgcn.image.gather4.c.lz.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_o_2d,               // llvm.amdgcn.image.gather4.c.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_o_2darray,          // llvm.amdgcn.image.gather4.c.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_c_o_cube,             // llvm.amdgcn.image.gather4.c.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_cl_2d,                // llvm.amdgcn.image.gather4.cl.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_cl_2darray,           // llvm.amdgcn.image.gather4.cl.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_cl_cube,              // llvm.amdgcn.image.gather4.cl.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_cl_o_2d,              // llvm.amdgcn.image.gather4.cl.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_cl_o_2darray,         // llvm.amdgcn.image.gather4.cl.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_cl_o_cube,            // llvm.amdgcn.image.gather4.cl.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_cube,                 // llvm.amdgcn.image.gather4.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_l_2d,                 // llvm.amdgcn.image.gather4.l.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_l_2darray,            // llvm.amdgcn.image.gather4.l.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_l_cube,               // llvm.amdgcn.image.gather4.l.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_l_o_2d,               // llvm.amdgcn.image.gather4.l.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_l_o_2darray,          // llvm.amdgcn.image.gather4.l.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_l_o_cube,             // llvm.amdgcn.image.gather4.l.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_lz_2d,                // llvm.amdgcn.image.gather4.lz.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_lz_2darray,           // llvm.amdgcn.image.gather4.lz.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_lz_cube,              // llvm.amdgcn.image.gather4.lz.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_lz_o_2d,              // llvm.amdgcn.image.gather4.lz.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_lz_o_2darray,         // llvm.amdgcn.image.gather4.lz.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_lz_o_cube,            // llvm.amdgcn.image.gather4.lz.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_o_2d,                 // llvm.amdgcn.image.gather4.o.2d (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_o_2darray,            // llvm.amdgcn.image.gather4.o.2darray (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_gather4_o_cube,               // llvm.amdgcn.image.gather4.o.cube (IntrinsicsAMDGPU.td:1340)
    amdgcn_image_getlod_1d,                    // llvm.amdgcn.image.getlod.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_getlod_1darray,               // llvm.amdgcn.image.getlod.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_getlod_2d,                    // llvm.amdgcn.image.getlod.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_getlod_2darray,               // llvm.amdgcn.image.getlod.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_getlod_3d,                    // llvm.amdgcn.image.getlod.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_getlod_cube,                  // llvm.amdgcn.image.getlod.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_getresinfo_1d,                // llvm.amdgcn.image.getresinfo.1d (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_getresinfo_1darray,           // llvm.amdgcn.image.getresinfo.1darray (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_getresinfo_2d,                // llvm.amdgcn.image.getresinfo.2d (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_getresinfo_2darray,           // llvm.amdgcn.image.getresinfo.2darray (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_getresinfo_2darraymsaa,       // llvm.amdgcn.image.getresinfo.2darraymsaa (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_getresinfo_2dmsaa,            // llvm.amdgcn.image.getresinfo.2dmsaa (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_getresinfo_3d,                // llvm.amdgcn.image.getresinfo.3d (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_getresinfo_cube,              // llvm.amdgcn.image.getresinfo.cube (IntrinsicsAMDGPU.td:1330)
    amdgcn_image_load_1d,                      // llvm.amdgcn.image.load.1d (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_1darray,                 // llvm.amdgcn.image.load.1darray (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_2d,                      // llvm.amdgcn.image.load.2d (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_2darray,                 // llvm.amdgcn.image.load.2darray (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_2darraymsaa,             // llvm.amdgcn.image.load.2darraymsaa (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_2dmsaa,                  // llvm.amdgcn.image.load.2dmsaa (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_3d,                      // llvm.amdgcn.image.load.3d (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_cube,                    // llvm.amdgcn.image.load.cube (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_load_mip_1d,                  // llvm.amdgcn.image.load.mip.1d (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_load_mip_1darray,             // llvm.amdgcn.image.load.mip.1darray (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_load_mip_2d,                  // llvm.amdgcn.image.load.mip.2d (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_load_mip_2darray,             // llvm.amdgcn.image.load.mip.2darray (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_load_mip_3d,                  // llvm.amdgcn.image.load.mip.3d (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_load_mip_cube,                // llvm.amdgcn.image.load.mip.cube (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_msaa_load_2darraymsaa,        // llvm.amdgcn.image.msaa.load.2darraymsaa (IntrinsicsAMDGPU.td:1279)
    amdgcn_image_msaa_load_2dmsaa,             // llvm.amdgcn.image.msaa.load.2dmsaa (IntrinsicsAMDGPU.td:1279)
    amdgcn_image_msaa_load_x_2darraymsaa,      // llvm.amdgcn.image.msaa.load.x.2darraymsaa (IntrinsicsAMDGPU.td:1272)
    amdgcn_image_msaa_load_x_2dmsaa,           // llvm.amdgcn.image.msaa.load.x.2dmsaa (IntrinsicsAMDGPU.td:1272)
    amdgcn_image_sample_1d,                    // llvm.amdgcn.image.sample.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_1d_nortn,              // llvm.amdgcn.image.sample.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_1darray,               // llvm.amdgcn.image.sample.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_1darray_nortn,         // llvm.amdgcn.image.sample.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_2d,                    // llvm.amdgcn.image.sample.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_2d_nortn,              // llvm.amdgcn.image.sample.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_2darray,               // llvm.amdgcn.image.sample.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_2darray_nortn,         // llvm.amdgcn.image.sample.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_3d,                    // llvm.amdgcn.image.sample.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_3d_nortn,              // llvm.amdgcn.image.sample.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_1d,                  // llvm.amdgcn.image.sample.b.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_1d_nortn,            // llvm.amdgcn.image.sample.b.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_1darray,             // llvm.amdgcn.image.sample.b.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_1darray_nortn,       // llvm.amdgcn.image.sample.b.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_2d,                  // llvm.amdgcn.image.sample.b.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_2d_nortn,            // llvm.amdgcn.image.sample.b.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_2darray,             // llvm.amdgcn.image.sample.b.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_2darray_nortn,       // llvm.amdgcn.image.sample.b.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_3d,                  // llvm.amdgcn.image.sample.b.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_3d_nortn,            // llvm.amdgcn.image.sample.b.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_1d,               // llvm.amdgcn.image.sample.b.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_1d_nortn,         // llvm.amdgcn.image.sample.b.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_1darray,          // llvm.amdgcn.image.sample.b.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_1darray_nortn,    // llvm.amdgcn.image.sample.b.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_2d,               // llvm.amdgcn.image.sample.b.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_2d_nortn,         // llvm.amdgcn.image.sample.b.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_2darray,          // llvm.amdgcn.image.sample.b.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_2darray_nortn,    // llvm.amdgcn.image.sample.b.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_3d,               // llvm.amdgcn.image.sample.b.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_3d_nortn,         // llvm.amdgcn.image.sample.b.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_cube,             // llvm.amdgcn.image.sample.b.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_cube_nortn,       // llvm.amdgcn.image.sample.b.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_o_1d,             // llvm.amdgcn.image.sample.b.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_o_1d_nortn,       // llvm.amdgcn.image.sample.b.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_o_1darray,        // llvm.amdgcn.image.sample.b.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_o_1darray_nortn,  // llvm.amdgcn.image.sample.b.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_o_2d,             // llvm.amdgcn.image.sample.b.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_o_2d_nortn,       // llvm.amdgcn.image.sample.b.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_o_2darray,        // llvm.amdgcn.image.sample.b.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_o_2darray_nortn,  // llvm.amdgcn.image.sample.b.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_o_3d,             // llvm.amdgcn.image.sample.b.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_o_3d_nortn,       // llvm.amdgcn.image.sample.b.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cl_o_cube,           // llvm.amdgcn.image.sample.b.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cl_o_cube_nortn,     // llvm.amdgcn.image.sample.b.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_cube,                // llvm.amdgcn.image.sample.b.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_cube_nortn,          // llvm.amdgcn.image.sample.b.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_o_1d,                // llvm.amdgcn.image.sample.b.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_o_1d_nortn,          // llvm.amdgcn.image.sample.b.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_o_1darray,           // llvm.amdgcn.image.sample.b.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_o_1darray_nortn,     // llvm.amdgcn.image.sample.b.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_o_2d,                // llvm.amdgcn.image.sample.b.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_o_2d_nortn,          // llvm.amdgcn.image.sample.b.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_o_2darray,           // llvm.amdgcn.image.sample.b.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_o_2darray_nortn,     // llvm.amdgcn.image.sample.b.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_o_3d,                // llvm.amdgcn.image.sample.b.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_o_3d_nortn,          // llvm.amdgcn.image.sample.b.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_b_o_cube,              // llvm.amdgcn.image.sample.b.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_b_o_cube_nortn,        // llvm.amdgcn.image.sample.b.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_1d,                  // llvm.amdgcn.image.sample.c.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_1d_nortn,            // llvm.amdgcn.image.sample.c.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_1darray,             // llvm.amdgcn.image.sample.c.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_1darray_nortn,       // llvm.amdgcn.image.sample.c.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_2d,                  // llvm.amdgcn.image.sample.c.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_2d_nortn,            // llvm.amdgcn.image.sample.c.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_2darray,             // llvm.amdgcn.image.sample.c.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_2darray_nortn,       // llvm.amdgcn.image.sample.c.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_3d,                  // llvm.amdgcn.image.sample.c.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_3d_nortn,            // llvm.amdgcn.image.sample.c.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_1d,                // llvm.amdgcn.image.sample.c.b.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_1d_nortn,          // llvm.amdgcn.image.sample.c.b.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_1darray,           // llvm.amdgcn.image.sample.c.b.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_1darray_nortn,     // llvm.amdgcn.image.sample.c.b.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_2d,                // llvm.amdgcn.image.sample.c.b.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_2d_nortn,          // llvm.amdgcn.image.sample.c.b.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_2darray,           // llvm.amdgcn.image.sample.c.b.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_2darray_nortn,     // llvm.amdgcn.image.sample.c.b.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_3d,                // llvm.amdgcn.image.sample.c.b.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_3d_nortn,          // llvm.amdgcn.image.sample.c.b.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_1d,             // llvm.amdgcn.image.sample.c.b.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_1d_nortn,       // llvm.amdgcn.image.sample.c.b.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_1darray,        // llvm.amdgcn.image.sample.c.b.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_1darray_nortn,  // llvm.amdgcn.image.sample.c.b.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_2d,             // llvm.amdgcn.image.sample.c.b.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_2d_nortn,       // llvm.amdgcn.image.sample.c.b.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_2darray,        // llvm.amdgcn.image.sample.c.b.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_2darray_nortn,  // llvm.amdgcn.image.sample.c.b.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_3d,             // llvm.amdgcn.image.sample.c.b.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_3d_nortn,       // llvm.amdgcn.image.sample.c.b.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_cube,           // llvm.amdgcn.image.sample.c.b.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_cube_nortn,     // llvm.amdgcn.image.sample.c.b.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_o_1d,           // llvm.amdgcn.image.sample.c.b.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_o_1d_nortn,     // llvm.amdgcn.image.sample.c.b.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_o_1darray,      // llvm.amdgcn.image.sample.c.b.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_o_1darray_nortn,  // llvm.amdgcn.image.sample.c.b.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_o_2d,           // llvm.amdgcn.image.sample.c.b.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_o_2d_nortn,     // llvm.amdgcn.image.sample.c.b.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_o_2darray,      // llvm.amdgcn.image.sample.c.b.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_o_2darray_nortn,  // llvm.amdgcn.image.sample.c.b.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_o_3d,           // llvm.amdgcn.image.sample.c.b.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_o_3d_nortn,     // llvm.amdgcn.image.sample.c.b.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cl_o_cube,         // llvm.amdgcn.image.sample.c.b.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cl_o_cube_nortn,   // llvm.amdgcn.image.sample.c.b.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_cube,              // llvm.amdgcn.image.sample.c.b.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_cube_nortn,        // llvm.amdgcn.image.sample.c.b.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_o_1d,              // llvm.amdgcn.image.sample.c.b.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_o_1d_nortn,        // llvm.amdgcn.image.sample.c.b.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_o_1darray,         // llvm.amdgcn.image.sample.c.b.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_o_1darray_nortn,   // llvm.amdgcn.image.sample.c.b.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_o_2d,              // llvm.amdgcn.image.sample.c.b.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_o_2d_nortn,        // llvm.amdgcn.image.sample.c.b.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_o_2darray,         // llvm.amdgcn.image.sample.c.b.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_o_2darray_nortn,   // llvm.amdgcn.image.sample.c.b.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_o_3d,              // llvm.amdgcn.image.sample.c.b.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_o_3d_nortn,        // llvm.amdgcn.image.sample.c.b.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_b_o_cube,            // llvm.amdgcn.image.sample.c.b.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_b_o_cube_nortn,      // llvm.amdgcn.image.sample.c.b.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_1d,               // llvm.amdgcn.image.sample.c.cd.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_1d_nortn,         // llvm.amdgcn.image.sample.c.cd.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_1darray,          // llvm.amdgcn.image.sample.c.cd.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_1darray_nortn,    // llvm.amdgcn.image.sample.c.cd.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_2d,               // llvm.amdgcn.image.sample.c.cd.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_2d_nortn,         // llvm.amdgcn.image.sample.c.cd.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_2darray,          // llvm.amdgcn.image.sample.c.cd.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_2darray_nortn,    // llvm.amdgcn.image.sample.c.cd.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_3d,               // llvm.amdgcn.image.sample.c.cd.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_3d_nortn,         // llvm.amdgcn.image.sample.c.cd.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_1d,            // llvm.amdgcn.image.sample.c.cd.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_1d_nortn,      // llvm.amdgcn.image.sample.c.cd.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_1darray,       // llvm.amdgcn.image.sample.c.cd.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_1darray_nortn,  // llvm.amdgcn.image.sample.c.cd.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_2d,            // llvm.amdgcn.image.sample.c.cd.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_2d_nortn,      // llvm.amdgcn.image.sample.c.cd.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_2darray,       // llvm.amdgcn.image.sample.c.cd.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_2darray_nortn,  // llvm.amdgcn.image.sample.c.cd.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_3d,            // llvm.amdgcn.image.sample.c.cd.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_3d_nortn,      // llvm.amdgcn.image.sample.c.cd.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_cube,          // llvm.amdgcn.image.sample.c.cd.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_cube_nortn,    // llvm.amdgcn.image.sample.c.cd.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_o_1d,          // llvm.amdgcn.image.sample.c.cd.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_o_1d_nortn,    // llvm.amdgcn.image.sample.c.cd.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_o_1darray,     // llvm.amdgcn.image.sample.c.cd.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_o_1darray_nortn,  // llvm.amdgcn.image.sample.c.cd.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_o_2d,          // llvm.amdgcn.image.sample.c.cd.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_o_2d_nortn,    // llvm.amdgcn.image.sample.c.cd.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_o_2darray,     // llvm.amdgcn.image.sample.c.cd.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_o_2darray_nortn,  // llvm.amdgcn.image.sample.c.cd.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_o_3d,          // llvm.amdgcn.image.sample.c.cd.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_o_3d_nortn,    // llvm.amdgcn.image.sample.c.cd.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cl_o_cube,        // llvm.amdgcn.image.sample.c.cd.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cl_o_cube_nortn,  // llvm.amdgcn.image.sample.c.cd.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_cube,             // llvm.amdgcn.image.sample.c.cd.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_cube_nortn,       // llvm.amdgcn.image.sample.c.cd.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_o_1d,             // llvm.amdgcn.image.sample.c.cd.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_o_1d_nortn,       // llvm.amdgcn.image.sample.c.cd.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_o_1darray,        // llvm.amdgcn.image.sample.c.cd.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_o_1darray_nortn,  // llvm.amdgcn.image.sample.c.cd.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_o_2d,             // llvm.amdgcn.image.sample.c.cd.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_o_2d_nortn,       // llvm.amdgcn.image.sample.c.cd.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_o_2darray,        // llvm.amdgcn.image.sample.c.cd.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_o_2darray_nortn,  // llvm.amdgcn.image.sample.c.cd.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_o_3d,             // llvm.amdgcn.image.sample.c.cd.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_o_3d_nortn,       // llvm.amdgcn.image.sample.c.cd.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cd_o_cube,           // llvm.amdgcn.image.sample.c.cd.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cd_o_cube_nortn,     // llvm.amdgcn.image.sample.c.cd.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_1d,               // llvm.amdgcn.image.sample.c.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_1d_nortn,         // llvm.amdgcn.image.sample.c.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_1darray,          // llvm.amdgcn.image.sample.c.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_1darray_nortn,    // llvm.amdgcn.image.sample.c.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_2d,               // llvm.amdgcn.image.sample.c.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_2d_nortn,         // llvm.amdgcn.image.sample.c.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_2darray,          // llvm.amdgcn.image.sample.c.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_2darray_nortn,    // llvm.amdgcn.image.sample.c.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_3d,               // llvm.amdgcn.image.sample.c.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_3d_nortn,         // llvm.amdgcn.image.sample.c.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_cube,             // llvm.amdgcn.image.sample.c.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_cube_nortn,       // llvm.amdgcn.image.sample.c.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_o_1d,             // llvm.amdgcn.image.sample.c.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_o_1d_nortn,       // llvm.amdgcn.image.sample.c.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_o_1darray,        // llvm.amdgcn.image.sample.c.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_o_1darray_nortn,  // llvm.amdgcn.image.sample.c.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_o_2d,             // llvm.amdgcn.image.sample.c.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_o_2d_nortn,       // llvm.amdgcn.image.sample.c.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_o_2darray,        // llvm.amdgcn.image.sample.c.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_o_2darray_nortn,  // llvm.amdgcn.image.sample.c.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_o_3d,             // llvm.amdgcn.image.sample.c.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_o_3d_nortn,       // llvm.amdgcn.image.sample.c.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cl_o_cube,           // llvm.amdgcn.image.sample.c.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cl_o_cube_nortn,     // llvm.amdgcn.image.sample.c.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_cube,                // llvm.amdgcn.image.sample.c.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_cube_nortn,          // llvm.amdgcn.image.sample.c.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_1d,                // llvm.amdgcn.image.sample.c.d.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_1d_nortn,          // llvm.amdgcn.image.sample.c.d.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_1darray,           // llvm.amdgcn.image.sample.c.d.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_1darray_nortn,     // llvm.amdgcn.image.sample.c.d.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_2d,                // llvm.amdgcn.image.sample.c.d.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_2d_nortn,          // llvm.amdgcn.image.sample.c.d.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_2darray,           // llvm.amdgcn.image.sample.c.d.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_2darray_nortn,     // llvm.amdgcn.image.sample.c.d.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_3d,                // llvm.amdgcn.image.sample.c.d.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_3d_nortn,          // llvm.amdgcn.image.sample.c.d.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_1d,             // llvm.amdgcn.image.sample.c.d.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_1d_nortn,       // llvm.amdgcn.image.sample.c.d.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_1darray,        // llvm.amdgcn.image.sample.c.d.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_1darray_nortn,  // llvm.amdgcn.image.sample.c.d.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_2d,             // llvm.amdgcn.image.sample.c.d.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_2d_nortn,       // llvm.amdgcn.image.sample.c.d.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_2darray,        // llvm.amdgcn.image.sample.c.d.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_2darray_nortn,  // llvm.amdgcn.image.sample.c.d.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_3d,             // llvm.amdgcn.image.sample.c.d.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_3d_nortn,       // llvm.amdgcn.image.sample.c.d.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_cube,           // llvm.amdgcn.image.sample.c.d.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_cube_nortn,     // llvm.amdgcn.image.sample.c.d.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_o_1d,           // llvm.amdgcn.image.sample.c.d.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_o_1d_nortn,     // llvm.amdgcn.image.sample.c.d.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_o_1darray,      // llvm.amdgcn.image.sample.c.d.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_o_1darray_nortn,  // llvm.amdgcn.image.sample.c.d.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_o_2d,           // llvm.amdgcn.image.sample.c.d.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_o_2d_nortn,     // llvm.amdgcn.image.sample.c.d.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_o_2darray,      // llvm.amdgcn.image.sample.c.d.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_o_2darray_nortn,  // llvm.amdgcn.image.sample.c.d.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_o_3d,           // llvm.amdgcn.image.sample.c.d.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_o_3d_nortn,     // llvm.amdgcn.image.sample.c.d.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cl_o_cube,         // llvm.amdgcn.image.sample.c.d.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cl_o_cube_nortn,   // llvm.amdgcn.image.sample.c.d.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_cube,              // llvm.amdgcn.image.sample.c.d.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_cube_nortn,        // llvm.amdgcn.image.sample.c.d.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_o_1d,              // llvm.amdgcn.image.sample.c.d.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_o_1d_nortn,        // llvm.amdgcn.image.sample.c.d.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_o_1darray,         // llvm.amdgcn.image.sample.c.d.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_o_1darray_nortn,   // llvm.amdgcn.image.sample.c.d.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_o_2d,              // llvm.amdgcn.image.sample.c.d.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_o_2d_nortn,        // llvm.amdgcn.image.sample.c.d.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_o_2darray,         // llvm.amdgcn.image.sample.c.d.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_o_2darray_nortn,   // llvm.amdgcn.image.sample.c.d.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_o_3d,              // llvm.amdgcn.image.sample.c.d.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_o_3d_nortn,        // llvm.amdgcn.image.sample.c.d.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_d_o_cube,            // llvm.amdgcn.image.sample.c.d.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_d_o_cube_nortn,      // llvm.amdgcn.image.sample.c.d.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_1d,                // llvm.amdgcn.image.sample.c.l.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_1d_nortn,          // llvm.amdgcn.image.sample.c.l.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_1darray,           // llvm.amdgcn.image.sample.c.l.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_1darray_nortn,     // llvm.amdgcn.image.sample.c.l.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_2d,                // llvm.amdgcn.image.sample.c.l.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_2d_nortn,          // llvm.amdgcn.image.sample.c.l.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_2darray,           // llvm.amdgcn.image.sample.c.l.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_2darray_nortn,     // llvm.amdgcn.image.sample.c.l.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_3d,                // llvm.amdgcn.image.sample.c.l.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_3d_nortn,          // llvm.amdgcn.image.sample.c.l.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_cube,              // llvm.amdgcn.image.sample.c.l.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_cube_nortn,        // llvm.amdgcn.image.sample.c.l.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_o_1d,              // llvm.amdgcn.image.sample.c.l.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_o_1d_nortn,        // llvm.amdgcn.image.sample.c.l.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_o_1darray,         // llvm.amdgcn.image.sample.c.l.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_o_1darray_nortn,   // llvm.amdgcn.image.sample.c.l.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_o_2d,              // llvm.amdgcn.image.sample.c.l.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_o_2d_nortn,        // llvm.amdgcn.image.sample.c.l.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_o_2darray,         // llvm.amdgcn.image.sample.c.l.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_o_2darray_nortn,   // llvm.amdgcn.image.sample.c.l.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_o_3d,              // llvm.amdgcn.image.sample.c.l.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_o_3d_nortn,        // llvm.amdgcn.image.sample.c.l.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_l_o_cube,            // llvm.amdgcn.image.sample.c.l.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_l_o_cube_nortn,      // llvm.amdgcn.image.sample.c.l.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_1d,               // llvm.amdgcn.image.sample.c.lz.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_1d_nortn,         // llvm.amdgcn.image.sample.c.lz.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_1darray,          // llvm.amdgcn.image.sample.c.lz.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_1darray_nortn,    // llvm.amdgcn.image.sample.c.lz.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_2d,               // llvm.amdgcn.image.sample.c.lz.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_2d_nortn,         // llvm.amdgcn.image.sample.c.lz.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_2darray,          // llvm.amdgcn.image.sample.c.lz.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_2darray_nortn,    // llvm.amdgcn.image.sample.c.lz.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_3d,               // llvm.amdgcn.image.sample.c.lz.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_3d_nortn,         // llvm.amdgcn.image.sample.c.lz.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_cube,             // llvm.amdgcn.image.sample.c.lz.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_cube_nortn,       // llvm.amdgcn.image.sample.c.lz.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_o_1d,             // llvm.amdgcn.image.sample.c.lz.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_o_1d_nortn,       // llvm.amdgcn.image.sample.c.lz.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_o_1darray,        // llvm.amdgcn.image.sample.c.lz.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_o_1darray_nortn,  // llvm.amdgcn.image.sample.c.lz.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_o_2d,             // llvm.amdgcn.image.sample.c.lz.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_o_2d_nortn,       // llvm.amdgcn.image.sample.c.lz.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_o_2darray,        // llvm.amdgcn.image.sample.c.lz.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_o_2darray_nortn,  // llvm.amdgcn.image.sample.c.lz.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_o_3d,             // llvm.amdgcn.image.sample.c.lz.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_o_3d_nortn,       // llvm.amdgcn.image.sample.c.lz.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_lz_o_cube,           // llvm.amdgcn.image.sample.c.lz.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_lz_o_cube_nortn,     // llvm.amdgcn.image.sample.c.lz.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_o_1d,                // llvm.amdgcn.image.sample.c.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_o_1d_nortn,          // llvm.amdgcn.image.sample.c.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_o_1darray,           // llvm.amdgcn.image.sample.c.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_o_1darray_nortn,     // llvm.amdgcn.image.sample.c.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_o_2d,                // llvm.amdgcn.image.sample.c.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_o_2d_nortn,          // llvm.amdgcn.image.sample.c.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_o_2darray,           // llvm.amdgcn.image.sample.c.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_o_2darray_nortn,     // llvm.amdgcn.image.sample.c.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_o_3d,                // llvm.amdgcn.image.sample.c.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_o_3d_nortn,          // llvm.amdgcn.image.sample.c.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_c_o_cube,              // llvm.amdgcn.image.sample.c.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_c_o_cube_nortn,        // llvm.amdgcn.image.sample.c.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_1d,                 // llvm.amdgcn.image.sample.cd.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_1d_nortn,           // llvm.amdgcn.image.sample.cd.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_1darray,            // llvm.amdgcn.image.sample.cd.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_1darray_nortn,      // llvm.amdgcn.image.sample.cd.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_2d,                 // llvm.amdgcn.image.sample.cd.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_2d_nortn,           // llvm.amdgcn.image.sample.cd.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_2darray,            // llvm.amdgcn.image.sample.cd.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_2darray_nortn,      // llvm.amdgcn.image.sample.cd.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_3d,                 // llvm.amdgcn.image.sample.cd.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_3d_nortn,           // llvm.amdgcn.image.sample.cd.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_1d,              // llvm.amdgcn.image.sample.cd.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_1d_nortn,        // llvm.amdgcn.image.sample.cd.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_1darray,         // llvm.amdgcn.image.sample.cd.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_1darray_nortn,   // llvm.amdgcn.image.sample.cd.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_2d,              // llvm.amdgcn.image.sample.cd.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_2d_nortn,        // llvm.amdgcn.image.sample.cd.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_2darray,         // llvm.amdgcn.image.sample.cd.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_2darray_nortn,   // llvm.amdgcn.image.sample.cd.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_3d,              // llvm.amdgcn.image.sample.cd.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_3d_nortn,        // llvm.amdgcn.image.sample.cd.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_cube,            // llvm.amdgcn.image.sample.cd.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_cube_nortn,      // llvm.amdgcn.image.sample.cd.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_o_1d,            // llvm.amdgcn.image.sample.cd.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_o_1d_nortn,      // llvm.amdgcn.image.sample.cd.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_o_1darray,       // llvm.amdgcn.image.sample.cd.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_o_1darray_nortn,  // llvm.amdgcn.image.sample.cd.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_o_2d,            // llvm.amdgcn.image.sample.cd.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_o_2d_nortn,      // llvm.amdgcn.image.sample.cd.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_o_2darray,       // llvm.amdgcn.image.sample.cd.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_o_2darray_nortn,  // llvm.amdgcn.image.sample.cd.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_o_3d,            // llvm.amdgcn.image.sample.cd.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_o_3d_nortn,      // llvm.amdgcn.image.sample.cd.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cl_o_cube,          // llvm.amdgcn.image.sample.cd.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cl_o_cube_nortn,    // llvm.amdgcn.image.sample.cd.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_cube,               // llvm.amdgcn.image.sample.cd.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_cube_nortn,         // llvm.amdgcn.image.sample.cd.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_o_1d,               // llvm.amdgcn.image.sample.cd.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_o_1d_nortn,         // llvm.amdgcn.image.sample.cd.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_o_1darray,          // llvm.amdgcn.image.sample.cd.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_o_1darray_nortn,    // llvm.amdgcn.image.sample.cd.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_o_2d,               // llvm.amdgcn.image.sample.cd.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_o_2d_nortn,         // llvm.amdgcn.image.sample.cd.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_o_2darray,          // llvm.amdgcn.image.sample.cd.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_o_2darray_nortn,    // llvm.amdgcn.image.sample.cd.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_o_3d,               // llvm.amdgcn.image.sample.cd.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_o_3d_nortn,         // llvm.amdgcn.image.sample.cd.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cd_o_cube,             // llvm.amdgcn.image.sample.cd.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cd_o_cube_nortn,       // llvm.amdgcn.image.sample.cd.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_1d,                 // llvm.amdgcn.image.sample.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_1d_nortn,           // llvm.amdgcn.image.sample.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_1darray,            // llvm.amdgcn.image.sample.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_1darray_nortn,      // llvm.amdgcn.image.sample.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_2d,                 // llvm.amdgcn.image.sample.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_2d_nortn,           // llvm.amdgcn.image.sample.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_2darray,            // llvm.amdgcn.image.sample.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_2darray_nortn,      // llvm.amdgcn.image.sample.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_3d,                 // llvm.amdgcn.image.sample.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_3d_nortn,           // llvm.amdgcn.image.sample.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_cube,               // llvm.amdgcn.image.sample.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_cube_nortn,         // llvm.amdgcn.image.sample.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_o_1d,               // llvm.amdgcn.image.sample.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_o_1d_nortn,         // llvm.amdgcn.image.sample.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_o_1darray,          // llvm.amdgcn.image.sample.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_o_1darray_nortn,    // llvm.amdgcn.image.sample.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_o_2d,               // llvm.amdgcn.image.sample.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_o_2d_nortn,         // llvm.amdgcn.image.sample.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_o_2darray,          // llvm.amdgcn.image.sample.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_o_2darray_nortn,    // llvm.amdgcn.image.sample.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_o_3d,               // llvm.amdgcn.image.sample.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_o_3d_nortn,         // llvm.amdgcn.image.sample.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cl_o_cube,             // llvm.amdgcn.image.sample.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cl_o_cube_nortn,       // llvm.amdgcn.image.sample.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_cube,                  // llvm.amdgcn.image.sample.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_cube_nortn,            // llvm.amdgcn.image.sample.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_1d,                  // llvm.amdgcn.image.sample.d.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_1d_nortn,            // llvm.amdgcn.image.sample.d.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_1darray,             // llvm.amdgcn.image.sample.d.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_1darray_nortn,       // llvm.amdgcn.image.sample.d.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_2d,                  // llvm.amdgcn.image.sample.d.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_2d_nortn,            // llvm.amdgcn.image.sample.d.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_2darray,             // llvm.amdgcn.image.sample.d.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_2darray_nortn,       // llvm.amdgcn.image.sample.d.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_3d,                  // llvm.amdgcn.image.sample.d.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_3d_nortn,            // llvm.amdgcn.image.sample.d.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_1d,               // llvm.amdgcn.image.sample.d.cl.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_1d_nortn,         // llvm.amdgcn.image.sample.d.cl.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_1darray,          // llvm.amdgcn.image.sample.d.cl.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_1darray_nortn,    // llvm.amdgcn.image.sample.d.cl.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_2d,               // llvm.amdgcn.image.sample.d.cl.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_2d_nortn,         // llvm.amdgcn.image.sample.d.cl.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_2darray,          // llvm.amdgcn.image.sample.d.cl.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_2darray_nortn,    // llvm.amdgcn.image.sample.d.cl.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_3d,               // llvm.amdgcn.image.sample.d.cl.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_3d_nortn,         // llvm.amdgcn.image.sample.d.cl.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_cube,             // llvm.amdgcn.image.sample.d.cl.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_cube_nortn,       // llvm.amdgcn.image.sample.d.cl.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_o_1d,             // llvm.amdgcn.image.sample.d.cl.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_o_1d_nortn,       // llvm.amdgcn.image.sample.d.cl.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_o_1darray,        // llvm.amdgcn.image.sample.d.cl.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_o_1darray_nortn,  // llvm.amdgcn.image.sample.d.cl.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_o_2d,             // llvm.amdgcn.image.sample.d.cl.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_o_2d_nortn,       // llvm.amdgcn.image.sample.d.cl.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_o_2darray,        // llvm.amdgcn.image.sample.d.cl.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_o_2darray_nortn,  // llvm.amdgcn.image.sample.d.cl.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_o_3d,             // llvm.amdgcn.image.sample.d.cl.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_o_3d_nortn,       // llvm.amdgcn.image.sample.d.cl.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cl_o_cube,           // llvm.amdgcn.image.sample.d.cl.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cl_o_cube_nortn,     // llvm.amdgcn.image.sample.d.cl.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_cube,                // llvm.amdgcn.image.sample.d.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_cube_nortn,          // llvm.amdgcn.image.sample.d.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_o_1d,                // llvm.amdgcn.image.sample.d.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_o_1d_nortn,          // llvm.amdgcn.image.sample.d.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_o_1darray,           // llvm.amdgcn.image.sample.d.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_o_1darray_nortn,     // llvm.amdgcn.image.sample.d.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_o_2d,                // llvm.amdgcn.image.sample.d.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_o_2d_nortn,          // llvm.amdgcn.image.sample.d.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_o_2darray,           // llvm.amdgcn.image.sample.d.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_o_2darray_nortn,     // llvm.amdgcn.image.sample.d.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_o_3d,                // llvm.amdgcn.image.sample.d.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_o_3d_nortn,          // llvm.amdgcn.image.sample.d.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_d_o_cube,              // llvm.amdgcn.image.sample.d.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_d_o_cube_nortn,        // llvm.amdgcn.image.sample.d.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_1d,                  // llvm.amdgcn.image.sample.l.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_1d_nortn,            // llvm.amdgcn.image.sample.l.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_1darray,             // llvm.amdgcn.image.sample.l.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_1darray_nortn,       // llvm.amdgcn.image.sample.l.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_2d,                  // llvm.amdgcn.image.sample.l.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_2d_nortn,            // llvm.amdgcn.image.sample.l.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_2darray,             // llvm.amdgcn.image.sample.l.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_2darray_nortn,       // llvm.amdgcn.image.sample.l.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_3d,                  // llvm.amdgcn.image.sample.l.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_3d_nortn,            // llvm.amdgcn.image.sample.l.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_cube,                // llvm.amdgcn.image.sample.l.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_cube_nortn,          // llvm.amdgcn.image.sample.l.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_o_1d,                // llvm.amdgcn.image.sample.l.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_o_1d_nortn,          // llvm.amdgcn.image.sample.l.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_o_1darray,           // llvm.amdgcn.image.sample.l.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_o_1darray_nortn,     // llvm.amdgcn.image.sample.l.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_o_2d,                // llvm.amdgcn.image.sample.l.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_o_2d_nortn,          // llvm.amdgcn.image.sample.l.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_o_2darray,           // llvm.amdgcn.image.sample.l.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_o_2darray_nortn,     // llvm.amdgcn.image.sample.l.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_o_3d,                // llvm.amdgcn.image.sample.l.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_o_3d_nortn,          // llvm.amdgcn.image.sample.l.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_l_o_cube,              // llvm.amdgcn.image.sample.l.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_l_o_cube_nortn,        // llvm.amdgcn.image.sample.l.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_1d,                 // llvm.amdgcn.image.sample.lz.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_1d_nortn,           // llvm.amdgcn.image.sample.lz.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_1darray,            // llvm.amdgcn.image.sample.lz.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_1darray_nortn,      // llvm.amdgcn.image.sample.lz.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_2d,                 // llvm.amdgcn.image.sample.lz.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_2d_nortn,           // llvm.amdgcn.image.sample.lz.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_2darray,            // llvm.amdgcn.image.sample.lz.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_2darray_nortn,      // llvm.amdgcn.image.sample.lz.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_3d,                 // llvm.amdgcn.image.sample.lz.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_3d_nortn,           // llvm.amdgcn.image.sample.lz.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_cube,               // llvm.amdgcn.image.sample.lz.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_cube_nortn,         // llvm.amdgcn.image.sample.lz.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_o_1d,               // llvm.amdgcn.image.sample.lz.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_o_1d_nortn,         // llvm.amdgcn.image.sample.lz.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_o_1darray,          // llvm.amdgcn.image.sample.lz.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_o_1darray_nortn,    // llvm.amdgcn.image.sample.lz.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_o_2d,               // llvm.amdgcn.image.sample.lz.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_o_2d_nortn,         // llvm.amdgcn.image.sample.lz.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_o_2darray,          // llvm.amdgcn.image.sample.lz.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_o_2darray_nortn,    // llvm.amdgcn.image.sample.lz.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_o_3d,               // llvm.amdgcn.image.sample.lz.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_o_3d_nortn,         // llvm.amdgcn.image.sample.lz.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_lz_o_cube,             // llvm.amdgcn.image.sample.lz.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_lz_o_cube_nortn,       // llvm.amdgcn.image.sample.lz.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_o_1d,                  // llvm.amdgcn.image.sample.o.1d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_o_1d_nortn,            // llvm.amdgcn.image.sample.o.1d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_o_1darray,             // llvm.amdgcn.image.sample.o.1darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_o_1darray_nortn,       // llvm.amdgcn.image.sample.o.1darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_o_2d,                  // llvm.amdgcn.image.sample.o.2d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_o_2d_nortn,            // llvm.amdgcn.image.sample.o.2d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_o_2darray,             // llvm.amdgcn.image.sample.o.2darray (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_o_2darray_nortn,       // llvm.amdgcn.image.sample.o.2darray.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_o_3d,                  // llvm.amdgcn.image.sample.o.3d (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_o_3d_nortn,            // llvm.amdgcn.image.sample.o.3d.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_sample_o_cube,                // llvm.amdgcn.image.sample.o.cube (IntrinsicsAMDGPU.td:1292)
    amdgcn_image_sample_o_cube_nortn,          // llvm.amdgcn.image.sample.o.cube.nortn (IntrinsicsAMDGPU.td:1309)
    amdgcn_image_store_1d,                     // llvm.amdgcn.image.store.1d (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_1darray,                // llvm.amdgcn.image.store.1darray (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_2d,                     // llvm.amdgcn.image.store.2d (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_2darray,                // llvm.amdgcn.image.store.2darray (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_2darraymsaa,            // llvm.amdgcn.image.store.2darraymsaa (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_2dmsaa,                 // llvm.amdgcn.image.store.2dmsaa (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_3d,                     // llvm.amdgcn.image.store.3d (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_cube,                   // llvm.amdgcn.image.store.cube (IntrinsicsAMDGPU.td:1243)
    amdgcn_image_store_mip_1d,                 // llvm.amdgcn.image.store.mip.1d (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_store_mip_1darray,            // llvm.amdgcn.image.store.mip.1darray (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_store_mip_2d,                 // llvm.amdgcn.image.store.mip.2d (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_store_mip_2darray,            // llvm.amdgcn.image.store.mip.2darray (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_store_mip_3d,                 // llvm.amdgcn.image.store.mip.3d (IntrinsicsAMDGPU.td:1229)
    amdgcn_image_store_mip_cube,               // llvm.amdgcn.image.store.mip.cube (IntrinsicsAMDGPU.td:1229)
    amdgcn_implicit_buffer_ptr,                // llvm.amdgcn.implicit.buffer.ptr (IntrinsicsAMDGPU.td:215)
    amdgcn_implicitarg_ptr,                    // llvm.amdgcn.implicitarg.ptr (IntrinsicsAMDGPU.td:195)
    amdgcn_init_exec,                          // llvm.amdgcn.init.exec (IntrinsicsAMDGPU.td:224)
    amdgcn_init_exec_from_input,               // llvm.amdgcn.init.exec.from.input (IntrinsicsAMDGPU.td:234)
    amdgcn_init_whole_wave,                    // llvm.amdgcn.init.whole.wave (IntrinsicsAMDGPU.td:247)
    amdgcn_interp_inreg_p10,                   // llvm.amdgcn.interp.inreg.p10 (IntrinsicsAMDGPU.td:2287)
    amdgcn_interp_inreg_p10_f16,               // llvm.amdgcn.interp.inreg.p10.f16 (IntrinsicsAMDGPU.td:2300)
    amdgcn_interp_inreg_p2,                    // llvm.amdgcn.interp.inreg.p2 (IntrinsicsAMDGPU.td:2293)
    amdgcn_interp_inreg_p2_f16,                // llvm.amdgcn.interp.inreg.p2.f16 (IntrinsicsAMDGPU.td:2308)
    amdgcn_interp_mov,                         // llvm.amdgcn.interp.mov (IntrinsicsAMDGPU.td:2225)
    amdgcn_interp_p1,                          // llvm.amdgcn.interp.p1 (IntrinsicsAMDGPU.td:2235)
    amdgcn_interp_p1_f16,                      // llvm.amdgcn.interp.p1.f16 (IntrinsicsAMDGPU.td:2253)
    amdgcn_interp_p10_rtz_f16,                 // llvm.amdgcn.interp.p10.rtz.f16 (IntrinsicsAMDGPU.td:2317)
    amdgcn_interp_p2,                          // llvm.amdgcn.interp.p2 (IntrinsicsAMDGPU.td:2243)
    amdgcn_interp_p2_f16,                      // llvm.amdgcn.interp.p2.f16 (IntrinsicsAMDGPU.td:2262)
    amdgcn_interp_p2_rtz_f16,                  // llvm.amdgcn.interp.p2.rtz.f16 (IntrinsicsAMDGPU.td:2326)
    amdgcn_inverse_ballot,                     // llvm.amdgcn.inverse.ballot (IntrinsicsAMDGPU.td:2423)
    amdgcn_is_private,                         // llvm.amdgcn.is.private (IntrinsicsAMDGPU.td:2648)
    amdgcn_is_shared,                          // llvm.amdgcn.is.shared (IntrinsicsAMDGPU.td:2642)
    amdgcn_kernarg_segment_ptr,                // llvm.amdgcn.kernarg.segment.ptr (IntrinsicsAMDGPU.td:190)
    amdgcn_kill,                               // llvm.amdgcn.kill (IntrinsicsAMDGPU.td:2589)
    amdgcn_lds_direct_load,                    // llvm.amdgcn.lds.direct.load (IntrinsicsAMDGPU.td:2272)
    amdgcn_lds_kernel_id,                      // llvm.amdgcn.lds.kernel.id (IntrinsicsAMDGPU.td:212)
    amdgcn_lds_param_load,                     // llvm.amdgcn.lds.param.load (IntrinsicsAMDGPU.td:2280)
    amdgcn_lerp,                               // llvm.amdgcn.lerp (IntrinsicsAMDGPU.td:2367)
    amdgcn_live_mask,                          // llvm.amdgcn.live.mask (IntrinsicsAMDGPU.td:2340)
    amdgcn_load_to_lds,                        // llvm.amdgcn.load.to.lds (IntrinsicsAMDGPU.td:2796)
    amdgcn_log,                                // llvm.amdgcn.log (IntrinsicsAMDGPU.td:434)
    amdgcn_log_clamp,                          // llvm.amdgcn.log.clamp (IntrinsicsAMDGPU.td:447)
    amdgcn_loop,                               // llvm.amdgcn.loop (IntrinsicsAMDGPU.td:3831)
    amdgcn_make_buffer_rsrc,                   // llvm.amdgcn.make.buffer.rsrc (IntrinsicsAMDGPU.td:1419)
    amdgcn_mbcnt_hi,                           // llvm.amdgcn.mbcnt.hi (IntrinsicsAMDGPU.td:2349)
    amdgcn_mbcnt_lo,                           // llvm.amdgcn.mbcnt.lo (IntrinsicsAMDGPU.td:2344)
    amdgcn_mfma_f32_16x16x16bf16_1k,           // llvm.amdgcn.mfma.f32.16x16x16bf16.1k (IntrinsicsAMDGPU.td:3478)
    amdgcn_mfma_f32_16x16x16f16,               // llvm.amdgcn.mfma.f32.16x16x16f16 (IntrinsicsAMDGPU.td:3456)
    amdgcn_mfma_f32_16x16x1f32,                // llvm.amdgcn.mfma.f32.16x16x1f32 (IntrinsicsAMDGPU.td:3448)
    amdgcn_mfma_f32_16x16x2bf16,               // llvm.amdgcn.mfma.f32.16x16x2bf16 (IntrinsicsAMDGPU.td:3463)
    amdgcn_mfma_f32_16x16x32_bf16,             // llvm.amdgcn.mfma.f32.16x16x32.bf16 (IntrinsicsAMDGPU.td:3620)
    amdgcn_mfma_f32_16x16x32_bf8_bf8,          // llvm.amdgcn.mfma.f32.16x16x32.bf8.bf8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_16x16x32_bf8_fp8,          // llvm.amdgcn.mfma.f32.16x16x32.bf8.fp8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_16x16x32_f16,              // llvm.amdgcn.mfma.f32.16x16x32.f16 (IntrinsicsAMDGPU.td:3616)
    amdgcn_mfma_f32_16x16x32_fp8_bf8,          // llvm.amdgcn.mfma.f32.16x16x32.fp8.bf8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_16x16x32_fp8_fp8,          // llvm.amdgcn.mfma.f32.16x16x32.fp8.fp8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_16x16x4bf16_1k,            // llvm.amdgcn.mfma.f32.16x16x4bf16.1k (IntrinsicsAMDGPU.td:3475)
    amdgcn_mfma_f32_16x16x4f16,                // llvm.amdgcn.mfma.f32.16x16x4f16 (IntrinsicsAMDGPU.td:3453)
    amdgcn_mfma_f32_16x16x4f32,                // llvm.amdgcn.mfma.f32.16x16x4f32 (IntrinsicsAMDGPU.td:3451)
    amdgcn_mfma_f32_16x16x8_xf32,              // llvm.amdgcn.mfma.f32.16x16x8.xf32 (IntrinsicsAMDGPU.td:3519)
    amdgcn_mfma_f32_16x16x8bf16,               // llvm.amdgcn.mfma.f32.16x16x8bf16 (IntrinsicsAMDGPU.td:3466)
    amdgcn_mfma_f32_32x32x16_bf16,             // llvm.amdgcn.mfma.f32.32x32x16.bf16 (IntrinsicsAMDGPU.td:3621)
    amdgcn_mfma_f32_32x32x16_bf8_bf8,          // llvm.amdgcn.mfma.f32.32x32x16.bf8.bf8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_32x32x16_bf8_fp8,          // llvm.amdgcn.mfma.f32.32x32x16.bf8.fp8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_32x32x16_f16,              // llvm.amdgcn.mfma.f32.32x32x16.f16 (IntrinsicsAMDGPU.td:3617)
    amdgcn_mfma_f32_32x32x16_fp8_bf8,          // llvm.amdgcn.mfma.f32.32x32x16.fp8.bf8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_32x32x16_fp8_fp8,          // llvm.amdgcn.mfma.f32.32x32x16.fp8.fp8 (IntrinsicsAMDGPU.td:3496)
    amdgcn_mfma_f32_32x32x1f32,                // llvm.amdgcn.mfma.f32.32x32x1f32 (IntrinsicsAMDGPU.td:3447)
    amdgcn_mfma_f32_32x32x2bf16,               // llvm.amdgcn.mfma.f32.32x32x2bf16 (IntrinsicsAMDGPU.td:3462)
    amdgcn_mfma_f32_32x32x2f32,                // llvm.amdgcn.mfma.f32.32x32x2f32 (IntrinsicsAMDGPU.td:3450)
    amdgcn_mfma_f32_32x32x4_xf32,              // llvm.amdgcn.mfma.f32.32x32x4.xf32 (IntrinsicsAMDGPU.td:3520)
    amdgcn_mfma_f32_32x32x4bf16,               // llvm.amdgcn.mfma.f32.32x32x4bf16 (IntrinsicsAMDGPU.td:3465)
    amdgcn_mfma_f32_32x32x4bf16_1k,            // llvm.amdgcn.mfma.f32.32x32x4bf16.1k (IntrinsicsAMDGPU.td:3474)
    amdgcn_mfma_f32_32x32x4f16,                // llvm.amdgcn.mfma.f32.32x32x4f16 (IntrinsicsAMDGPU.td:3452)
    amdgcn_mfma_f32_32x32x8bf16_1k,            // llvm.amdgcn.mfma.f32.32x32x8bf16.1k (IntrinsicsAMDGPU.td:3477)
    amdgcn_mfma_f32_32x32x8f16,                // llvm.amdgcn.mfma.f32.32x32x8f16 (IntrinsicsAMDGPU.td:3455)
    amdgcn_mfma_f32_4x4x1f32,                  // llvm.amdgcn.mfma.f32.4x4x1f32 (IntrinsicsAMDGPU.td:3449)
    amdgcn_mfma_f32_4x4x2bf16,                 // llvm.amdgcn.mfma.f32.4x4x2bf16 (IntrinsicsAMDGPU.td:3464)
    amdgcn_mfma_f32_4x4x4bf16_1k,              // llvm.amdgcn.mfma.f32.4x4x4bf16.1k (IntrinsicsAMDGPU.td:3476)
    amdgcn_mfma_f32_4x4x4f16,                  // llvm.amdgcn.mfma.f32.4x4x4f16 (IntrinsicsAMDGPU.td:3454)
    amdgcn_mfma_f64_16x16x4f64,                // llvm.amdgcn.mfma.f64.16x16x4f64 (IntrinsicsAMDGPU.td:3483)
    amdgcn_mfma_f64_4x4x4f64,                  // llvm.amdgcn.mfma.f64.4x4x4f64 (IntrinsicsAMDGPU.td:3484)
    amdgcn_mfma_i32_16x16x16i8,                // llvm.amdgcn.mfma.i32.16x16x16i8 (IntrinsicsAMDGPU.td:3461)
    amdgcn_mfma_i32_16x16x32_i8,               // llvm.amdgcn.mfma.i32.16x16x32.i8 (IntrinsicsAMDGPU.td:3517)
    amdgcn_mfma_i32_16x16x4i8,                 // llvm.amdgcn.mfma.i32.16x16x4i8 (IntrinsicsAMDGPU.td:3458)
    amdgcn_mfma_i32_16x16x64_i8,               // llvm.amdgcn.mfma.i32.16x16x64.i8 (IntrinsicsAMDGPU.td:3618)
    amdgcn_mfma_i32_32x32x16_i8,               // llvm.amdgcn.mfma.i32.32x32x16.i8 (IntrinsicsAMDGPU.td:3518)
    amdgcn_mfma_i32_32x32x32_i8,               // llvm.amdgcn.mfma.i32.32x32x32.i8 (IntrinsicsAMDGPU.td:3619)
    amdgcn_mfma_i32_32x32x4i8,                 // llvm.amdgcn.mfma.i32.32x32x4i8 (IntrinsicsAMDGPU.td:3457)
    amdgcn_mfma_i32_32x32x8i8,                 // llvm.amdgcn.mfma.i32.32x32x8i8 (IntrinsicsAMDGPU.td:3460)
    amdgcn_mfma_i32_4x4x4i8,                   // llvm.amdgcn.mfma.i32.4x4x4i8 (IntrinsicsAMDGPU.td:3459)
    amdgcn_mfma_scale_f32_16x16x128_f8f6f4,    // llvm.amdgcn.mfma.scale.f32.16x16x128.f8f6f4 (IntrinsicsAMDGPU.td:3622)
    amdgcn_mfma_scale_f32_32x32x64_f8f6f4,     // llvm.amdgcn.mfma.scale.f32.32x32x64.f8f6f4 (IntrinsicsAMDGPU.td:3623)
    amdgcn_mov_dpp,                            // llvm.amdgcn.mov.dpp (IntrinsicsAMDGPU.td:2717)
    amdgcn_mov_dpp8,                           // llvm.amdgcn.mov.dpp8 (IntrinsicsAMDGPU.td:2843)
    amdgcn_mqsad_pk_u16_u8,                    // llvm.amdgcn.mqsad.pk.u16.u8 (IntrinsicsAMDGPU.td:2391)
    amdgcn_mqsad_u32_u8,                       // llvm.amdgcn.mqsad.u32.u8 (IntrinsicsAMDGPU.td:2395)
    amdgcn_msad_u8,                            // llvm.amdgcn.msad.u8 (IntrinsicsAMDGPU.td:2375)
    amdgcn_mul_i24,                            // llvm.amdgcn.mul.i24 (IntrinsicsAMDGPU.td:2491)
    amdgcn_mul_u24,                            // llvm.amdgcn.mul.u24 (IntrinsicsAMDGPU.td:2495)
    amdgcn_mulhi_i24,                          // llvm.amdgcn.mulhi.i24 (IntrinsicsAMDGPU.td:2499)
    amdgcn_mulhi_u24,                          // llvm.amdgcn.mulhi.u24 (IntrinsicsAMDGPU.td:2503)
    amdgcn_perm,                               // llvm.amdgcn.perm (IntrinsicsAMDGPU.td:2767)
    amdgcn_perm_pk16_b4_u4,                    // llvm.amdgcn.perm.pk16.b4.u4 (IntrinsicsAMDGPU.td:3748)
    amdgcn_perm_pk16_b6_u4,                    // llvm.amdgcn.perm.pk16.b6.u4 (IntrinsicsAMDGPU.td:3751)
    amdgcn_perm_pk16_b8_u4,                    // llvm.amdgcn.perm.pk16.b8.u4 (IntrinsicsAMDGPU.td:3754)
    amdgcn_permlane_bcast,                     // llvm.amdgcn.permlane.bcast (IntrinsicsAMDGPU.td:3719)
    amdgcn_permlane_down,                      // llvm.amdgcn.permlane.down (IntrinsicsAMDGPU.td:3731)
    amdgcn_permlane_idx_gen,                   // llvm.amdgcn.permlane.idx.gen (IntrinsicsAMDGPU.td:3743)
    amdgcn_permlane_up,                        // llvm.amdgcn.permlane.up (IntrinsicsAMDGPU.td:3725)
    amdgcn_permlane_xor,                       // llvm.amdgcn.permlane.xor (IntrinsicsAMDGPU.td:3737)
    amdgcn_permlane16,                         // llvm.amdgcn.permlane16 (IntrinsicsAMDGPU.td:2827)
    amdgcn_permlane16_swap,                    // llvm.amdgcn.permlane16.swap (IntrinsicsAMDGPU.td:3641)
    amdgcn_permlane16_var,                     // llvm.amdgcn.permlane16.var (IntrinsicsAMDGPU.td:3017)
    amdgcn_permlane32_swap,                    // llvm.amdgcn.permlane32.swap (IntrinsicsAMDGPU.td:3648)
    amdgcn_permlane64,                         // llvm.amdgcn.permlane64 (IntrinsicsAMDGPU.td:2876)
    amdgcn_permlanex16,                        // llvm.amdgcn.permlanex16 (IntrinsicsAMDGPU.td:2834)
    amdgcn_permlanex16_var,                    // llvm.amdgcn.permlanex16.var (IntrinsicsAMDGPU.td:3024)
    amdgcn_pk_add_max_i16,                     // llvm.amdgcn.pk.add.max.i16 (IntrinsicsAMDGPU.td:3766)
    amdgcn_pk_add_max_u16,                     // llvm.amdgcn.pk.add.max.u16 (IntrinsicsAMDGPU.td:3767)
    amdgcn_pk_add_min_i16,                     // llvm.amdgcn.pk.add.min.i16 (IntrinsicsAMDGPU.td:3768)
    amdgcn_pk_add_min_u16,                     // llvm.amdgcn.pk.add.min.u16 (IntrinsicsAMDGPU.td:3769)
    amdgcn_pops_exiting_wave_id,               // llvm.amdgcn.pops.exiting.wave.id (IntrinsicsAMDGPU.td:2819)
    amdgcn_prng_b32,                           // llvm.amdgcn.prng.b32 (IntrinsicsAMDGPU.td:881)
    amdgcn_ps_live,                            // llvm.amdgcn.ps.live (IntrinsicsAMDGPU.td:2333)
    amdgcn_qsad_pk_u16_u8,                     // llvm.amdgcn.qsad.pk.u16.u8 (IntrinsicsAMDGPU.td:2387)
    amdgcn_queue_ptr,                          // llvm.amdgcn.queue.ptr (IntrinsicsAMDGPU.td:185)
    amdgcn_raw_atomic_buffer_load,             // llvm.amdgcn.raw.atomic.buffer.load (IntrinsicsAMDGPU.td:1489)
    amdgcn_raw_buffer_atomic_add,              // llvm.amdgcn.raw.buffer.atomic.add (IntrinsicsAMDGPU.td:1680)
    amdgcn_raw_buffer_atomic_and,              // llvm.amdgcn.raw.buffer.atomic.and (IntrinsicsAMDGPU.td:1688)
    amdgcn_raw_buffer_atomic_cmpswap,          // llvm.amdgcn.raw.buffer.atomic.cmpswap (IntrinsicsAMDGPU.td:1695)
    amdgcn_raw_buffer_atomic_cond_sub_u32,     // llvm.amdgcn.raw.buffer.atomic.cond.sub.u32 (IntrinsicsAMDGPU.td:1693)
    amdgcn_raw_buffer_atomic_dec,              // llvm.amdgcn.raw.buffer.atomic.dec (IntrinsicsAMDGPU.td:1692)
    amdgcn_raw_buffer_atomic_fadd,             // llvm.amdgcn.raw.buffer.atomic.fadd (IntrinsicsAMDGPU.td:1746)
    amdgcn_raw_buffer_atomic_fmax,             // llvm.amdgcn.raw.buffer.atomic.fmax (IntrinsicsAMDGPU.td:1687)
    amdgcn_raw_buffer_atomic_fmin,             // llvm.amdgcn.raw.buffer.atomic.fmin (IntrinsicsAMDGPU.td:1684)
    amdgcn_raw_buffer_atomic_inc,              // llvm.amdgcn.raw.buffer.atomic.inc (IntrinsicsAMDGPU.td:1691)
    amdgcn_raw_buffer_atomic_or,               // llvm.amdgcn.raw.buffer.atomic.or (IntrinsicsAMDGPU.td:1689)
    amdgcn_raw_buffer_atomic_smax,             // llvm.amdgcn.raw.buffer.atomic.smax (IntrinsicsAMDGPU.td:1685)
    amdgcn_raw_buffer_atomic_smin,             // llvm.amdgcn.raw.buffer.atomic.smin (IntrinsicsAMDGPU.td:1682)
    amdgcn_raw_buffer_atomic_sub,              // llvm.amdgcn.raw.buffer.atomic.sub (IntrinsicsAMDGPU.td:1681)
    amdgcn_raw_buffer_atomic_sub_clamp_u32,    // llvm.amdgcn.raw.buffer.atomic.sub.clamp.u32 (IntrinsicsAMDGPU.td:1694)
    amdgcn_raw_buffer_atomic_swap,             // llvm.amdgcn.raw.buffer.atomic.swap (IntrinsicsAMDGPU.td:1679)
    amdgcn_raw_buffer_atomic_umax,             // llvm.amdgcn.raw.buffer.atomic.umax (IntrinsicsAMDGPU.td:1686)
    amdgcn_raw_buffer_atomic_umin,             // llvm.amdgcn.raw.buffer.atomic.umin (IntrinsicsAMDGPU.td:1683)
    amdgcn_raw_buffer_atomic_xor,              // llvm.amdgcn.raw.buffer.atomic.xor (IntrinsicsAMDGPU.td:1690)
    amdgcn_raw_buffer_load,                    // llvm.amdgcn.raw.buffer.load (IntrinsicsAMDGPU.td:1476)
    amdgcn_raw_buffer_load_format,             // llvm.amdgcn.raw.buffer.load.format (IntrinsicsAMDGPU.td:1475)
    amdgcn_raw_buffer_load_lds,                // llvm.amdgcn.raw.buffer.load.lds (IntrinsicsAMDGPU.td:2000)
    amdgcn_raw_buffer_store,                   // llvm.amdgcn.raw.buffer.store (IntrinsicsAMDGPU.td:1610)
    amdgcn_raw_buffer_store_format,            // llvm.amdgcn.raw.buffer.store.format (IntrinsicsAMDGPU.td:1609)
    amdgcn_raw_ptr_atomic_buffer_load,         // llvm.amdgcn.raw.ptr.atomic.buffer.load (IntrinsicsAMDGPU.td:1520)
    amdgcn_raw_ptr_buffer_atomic_add,          // llvm.amdgcn.raw.ptr.buffer.atomic.add (IntrinsicsAMDGPU.td:1718)
    amdgcn_raw_ptr_buffer_atomic_and,          // llvm.amdgcn.raw.ptr.buffer.atomic.and (IntrinsicsAMDGPU.td:1726)
    amdgcn_raw_ptr_buffer_atomic_cmpswap,      // llvm.amdgcn.raw.ptr.buffer.atomic.cmpswap (IntrinsicsAMDGPU.td:1733)
    amdgcn_raw_ptr_buffer_atomic_cond_sub_u32,  // llvm.amdgcn.raw.ptr.buffer.atomic.cond.sub.u32 (IntrinsicsAMDGPU.td:1731)
    amdgcn_raw_ptr_buffer_atomic_dec,          // llvm.amdgcn.raw.ptr.buffer.atomic.dec (IntrinsicsAMDGPU.td:1730)
    amdgcn_raw_ptr_buffer_atomic_fadd,         // llvm.amdgcn.raw.ptr.buffer.atomic.fadd (IntrinsicsAMDGPU.td:1749)
    amdgcn_raw_ptr_buffer_atomic_fmax,         // llvm.amdgcn.raw.ptr.buffer.atomic.fmax (IntrinsicsAMDGPU.td:1725)
    amdgcn_raw_ptr_buffer_atomic_fmin,         // llvm.amdgcn.raw.ptr.buffer.atomic.fmin (IntrinsicsAMDGPU.td:1722)
    amdgcn_raw_ptr_buffer_atomic_inc,          // llvm.amdgcn.raw.ptr.buffer.atomic.inc (IntrinsicsAMDGPU.td:1729)
    amdgcn_raw_ptr_buffer_atomic_or,           // llvm.amdgcn.raw.ptr.buffer.atomic.or (IntrinsicsAMDGPU.td:1727)
    amdgcn_raw_ptr_buffer_atomic_smax,         // llvm.amdgcn.raw.ptr.buffer.atomic.smax (IntrinsicsAMDGPU.td:1723)
    amdgcn_raw_ptr_buffer_atomic_smin,         // llvm.amdgcn.raw.ptr.buffer.atomic.smin (IntrinsicsAMDGPU.td:1720)
    amdgcn_raw_ptr_buffer_atomic_sub,          // llvm.amdgcn.raw.ptr.buffer.atomic.sub (IntrinsicsAMDGPU.td:1719)
    amdgcn_raw_ptr_buffer_atomic_sub_clamp_u32,  // llvm.amdgcn.raw.ptr.buffer.atomic.sub.clamp.u32 (IntrinsicsAMDGPU.td:1732)
    amdgcn_raw_ptr_buffer_atomic_swap,         // llvm.amdgcn.raw.ptr.buffer.atomic.swap (IntrinsicsAMDGPU.td:1717)
    amdgcn_raw_ptr_buffer_atomic_umax,         // llvm.amdgcn.raw.ptr.buffer.atomic.umax (IntrinsicsAMDGPU.td:1724)
    amdgcn_raw_ptr_buffer_atomic_umin,         // llvm.amdgcn.raw.ptr.buffer.atomic.umin (IntrinsicsAMDGPU.td:1721)
    amdgcn_raw_ptr_buffer_atomic_xor,          // llvm.amdgcn.raw.ptr.buffer.atomic.xor (IntrinsicsAMDGPU.td:1728)
    amdgcn_raw_ptr_buffer_load,                // llvm.amdgcn.raw.ptr.buffer.load (IntrinsicsAMDGPU.td:1507)
    amdgcn_raw_ptr_buffer_load_format,         // llvm.amdgcn.raw.ptr.buffer.load.format (IntrinsicsAMDGPU.td:1506)
    amdgcn_raw_ptr_buffer_load_lds,            // llvm.amdgcn.raw.ptr.buffer.load.lds (IntrinsicsAMDGPU.td:2024)
    amdgcn_raw_ptr_buffer_store,               // llvm.amdgcn.raw.ptr.buffer.store (IntrinsicsAMDGPU.td:1629)
    amdgcn_raw_ptr_buffer_store_format,        // llvm.amdgcn.raw.ptr.buffer.store.format (IntrinsicsAMDGPU.td:1628)
    amdgcn_raw_ptr_tbuffer_load,               // llvm.amdgcn.raw.ptr.tbuffer.load (IntrinsicsAMDGPU.td:1856)
    amdgcn_raw_ptr_tbuffer_store,              // llvm.amdgcn.raw.ptr.tbuffer.store (IntrinsicsAMDGPU.td:1891)
    amdgcn_raw_tbuffer_load,                   // llvm.amdgcn.raw.tbuffer.load (IntrinsicsAMDGPU.td:1840)
    amdgcn_raw_tbuffer_store,                  // llvm.amdgcn.raw.tbuffer.store (IntrinsicsAMDGPU.td:1873)
    amdgcn_rcp,                                // llvm.amdgcn.rcp (IntrinsicsAMDGPU.td:466)
    amdgcn_rcp_legacy,                         // llvm.amdgcn.rcp.legacy (IntrinsicsAMDGPU.td:470)
    amdgcn_readfirstlane,                      // llvm.amdgcn.readfirstlane (IntrinsicsAMDGPU.td:2462)
    amdgcn_readlane,                           // llvm.amdgcn.readlane (IntrinsicsAMDGPU.td:2468)
    amdgcn_reloc_constant,                     // llvm.amdgcn.reloc.constant (IntrinsicsAMDGPU.td:257)
    amdgcn_rsq,                                // llvm.amdgcn.rsq (IntrinsicsAMDGPU.td:478)
    amdgcn_rsq_clamp,                          // llvm.amdgcn.rsq.clamp (IntrinsicsAMDGPU.td:488)
    amdgcn_rsq_legacy,                         // llvm.amdgcn.rsq.legacy (IntrinsicsAMDGPU.td:482)
    amdgcn_s_barrier,                          // llvm.amdgcn.s.barrier (IntrinsicsAMDGPU.td:282)
    amdgcn_s_barrier_init,                     // llvm.amdgcn.s.barrier.init (IntrinsicsAMDGPU.td:307)
    amdgcn_s_barrier_join,                     // llvm.amdgcn.s.barrier.join (IntrinsicsAMDGPU.td:313)
    amdgcn_s_barrier_leave,                    // llvm.amdgcn.s.barrier.leave (IntrinsicsAMDGPU.td:330)
    amdgcn_s_barrier_signal,                   // llvm.amdgcn.s.barrier.signal (IntrinsicsAMDGPU.td:289)
    amdgcn_s_barrier_signal_isfirst,           // llvm.amdgcn.s.barrier.signal.isfirst (IntrinsicsAMDGPU.td:301)
    amdgcn_s_barrier_signal_var,               // llvm.amdgcn.s.barrier.signal.var (IntrinsicsAMDGPU.td:295)
    amdgcn_s_barrier_wait,                     // llvm.amdgcn.s.barrier.wait (IntrinsicsAMDGPU.td:324)
    amdgcn_s_bitreplicate,                     // llvm.amdgcn.s.bitreplicate (IntrinsicsAMDGPU.td:2429)
    amdgcn_s_buffer_load,                      // llvm.amdgcn.s.buffer.load (IntrinsicsAMDGPU.td:1432)
    amdgcn_s_buffer_prefetch_data,             // llvm.amdgcn.s.buffer.prefetch.data (IntrinsicsAMDGPU.td:2071)
    amdgcn_s_cluster_barrier,                  // llvm.amdgcn.s.cluster.barrier (IntrinsicsAMDGPU.td:3667)
    amdgcn_s_dcache_inv,                       // llvm.amdgcn.s.dcache.inv (IntrinsicsAMDGPU.td:2132)
    amdgcn_s_dcache_inv_vol,                   // llvm.amdgcn.s.dcache.inv.vol (IntrinsicsAMDGPU.td:2701)
    amdgcn_s_dcache_wb,                        // llvm.amdgcn.s.dcache.wb (IntrinsicsAMDGPU.td:2742)
    amdgcn_s_dcache_wb_vol,                    // llvm.amdgcn.s.dcache.wb.vol (IntrinsicsAMDGPU.td:2746)
    amdgcn_s_decperflevel,                     // llvm.amdgcn.s.decperflevel (IntrinsicsAMDGPU.td:2163)
    amdgcn_s_get_barrier_state,                // llvm.amdgcn.s.get.barrier.state (IntrinsicsAMDGPU.td:336)
    amdgcn_s_get_named_barrier_state,          // llvm.amdgcn.s.get.named.barrier.state (IntrinsicsAMDGPU.td:342)
    amdgcn_s_get_waveid_in_workgroup,          // llvm.amdgcn.s.get.waveid.in.workgroup (IntrinsicsAMDGPU.td:2849)
    amdgcn_s_getpc,                            // llvm.amdgcn.s.getpc (IntrinsicsAMDGPU.td:2218)
    amdgcn_s_getreg,                           // llvm.amdgcn.s.getreg (IntrinsicsAMDGPU.td:2194)
    amdgcn_s_incperflevel,                     // llvm.amdgcn.s.incperflevel (IntrinsicsAMDGPU.td:2157)
    amdgcn_s_memrealtime,                      // llvm.amdgcn.s.memrealtime (IntrinsicsAMDGPU.td:2750)
    amdgcn_s_memtime,                          // llvm.amdgcn.s.memtime (IntrinsicsAMDGPU.td:2136)
    amdgcn_s_monitor_sleep,                    // llvm.amdgcn.s.monitor.sleep (IntrinsicsAMDGPU.td:3695)
    amdgcn_s_nop,                              // llvm.amdgcn.s.nop (IntrinsicsAMDGPU.td:2152)
    amdgcn_s_prefetch_data,                    // llvm.amdgcn.s.prefetch.data (IntrinsicsAMDGPU.td:3145)
    amdgcn_s_quadmask,                         // llvm.amdgcn.s.quadmask (IntrinsicsAMDGPU.td:2434)
    amdgcn_s_sendmsg,                          // llvm.amdgcn.s.sendmsg (IntrinsicsAMDGPU.td:268)
    amdgcn_s_sendmsg_rtn,                      // llvm.amdgcn.s.sendmsg.rtn (IntrinsicsAMDGPU.td:278)
    amdgcn_s_sendmsghalt,                      // llvm.amdgcn.s.sendmsghalt (IntrinsicsAMDGPU.td:271)
    amdgcn_s_sethalt,                          // llvm.amdgcn.s.sethalt (IntrinsicsAMDGPU.td:2169)
    amdgcn_s_setprio,                          // llvm.amdgcn.s.setprio (IntrinsicsAMDGPU.td:2173)
    amdgcn_s_setprio_inc_wg,                   // llvm.amdgcn.s.setprio.inc.wg (IntrinsicsAMDGPU.td:2178)
    amdgcn_s_setreg,                           // llvm.amdgcn.s.setreg (IntrinsicsAMDGPU.td:2204)
    amdgcn_s_sleep,                            // llvm.amdgcn.s.sleep (IntrinsicsAMDGPU.td:2140)
    amdgcn_s_sleep_var,                        // llvm.amdgcn.s.sleep.var (IntrinsicsAMDGPU.td:2146)
    amdgcn_s_ttracedata,                       // llvm.amdgcn.s.ttracedata (IntrinsicsAMDGPU.td:2183)
    amdgcn_s_ttracedata_imm,                   // llvm.amdgcn.s.ttracedata.imm (IntrinsicsAMDGPU.td:2188)
    amdgcn_s_wait_asynccnt,                    // llvm.amdgcn.s.wait.asynccnt (IntrinsicsAMDGPU.td:3677)
    amdgcn_s_wait_bvhcnt,                      // llvm.amdgcn.s.wait.bvhcnt (IntrinsicsAMDGPU.td:392)
    amdgcn_s_wait_dscnt,                       // llvm.amdgcn.s.wait.dscnt (IntrinsicsAMDGPU.td:393)
    amdgcn_s_wait_event_export_ready,          // llvm.amdgcn.s.wait.event.export.ready (IntrinsicsAMDGPU.td:2907)
    amdgcn_s_wait_expcnt,                      // llvm.amdgcn.s.wait.expcnt (IntrinsicsAMDGPU.td:394)
    amdgcn_s_wait_kmcnt,                       // llvm.amdgcn.s.wait.kmcnt (IntrinsicsAMDGPU.td:395)
    amdgcn_s_wait_loadcnt,                     // llvm.amdgcn.s.wait.loadcnt (IntrinsicsAMDGPU.td:396)
    amdgcn_s_wait_samplecnt,                   // llvm.amdgcn.s.wait.samplecnt (IntrinsicsAMDGPU.td:397)
    amdgcn_s_wait_storecnt,                    // llvm.amdgcn.s.wait.storecnt (IntrinsicsAMDGPU.td:398)
    amdgcn_s_wait_tensorcnt,                   // llvm.amdgcn.s.wait.tensorcnt (IntrinsicsAMDGPU.td:3679)
    amdgcn_s_waitcnt,                          // llvm.amdgcn.s.waitcnt (IntrinsicsAMDGPU.td:386)
    amdgcn_s_wakeup_barrier,                   // llvm.amdgcn.s.wakeup.barrier (IntrinsicsAMDGPU.td:319)
    amdgcn_s_wqm,                              // llvm.amdgcn.s.wqm (IntrinsicsAMDGPU.td:2440)
    amdgcn_sad_hi_u8,                          // llvm.amdgcn.sad.hi.u8 (IntrinsicsAMDGPU.td:2379)
    amdgcn_sad_u16,                            // llvm.amdgcn.sad.u16 (IntrinsicsAMDGPU.td:2383)
    amdgcn_sad_u8,                             // llvm.amdgcn.sad.u8 (IntrinsicsAMDGPU.td:2371)
    amdgcn_sat_pk4_i4_i8,                      // llvm.amdgcn.sat.pk4.i4.i8 (IntrinsicsAMDGPU.td:3712)
    amdgcn_sat_pk4_u4_u8,                      // llvm.amdgcn.sat.pk4.u4.u8 (IntrinsicsAMDGPU.td:3715)
    amdgcn_sbfe,                               // llvm.amdgcn.sbfe (IntrinsicsAMDGPU.td:2364)
    amdgcn_sched_barrier,                      // llvm.amdgcn.sched.barrier (IntrinsicsAMDGPU.td:363)
    amdgcn_sched_group_barrier,                // llvm.amdgcn.sched.group.barrier (IntrinsicsAMDGPU.td:375)
    amdgcn_sdot2,                              // llvm.amdgcn.sdot2 (IntrinsicsAMDGPU.td:3257)
    amdgcn_sdot4,                              // llvm.amdgcn.sdot4 (IntrinsicsAMDGPU.td:3287)
    amdgcn_sdot8,                              // llvm.amdgcn.sdot8 (IntrinsicsAMDGPU.td:3338)
    amdgcn_set_inactive,                       // llvm.amdgcn.set.inactive (IntrinsicsAMDGPU.td:2624)
    amdgcn_set_inactive_chain_arg,             // llvm.amdgcn.set.inactive.chain.arg (IntrinsicsAMDGPU.td:2635)
    amdgcn_sffbh,                              // llvm.amdgcn.sffbh (IntrinsicsAMDGPU.td:562)
    amdgcn_sin,                                // llvm.amdgcn.sin (IntrinsicsAMDGPU.td:422)
    amdgcn_smfmac_f32_16x16x128_bf8_bf8,       // llvm.amdgcn.smfmac.f32.16x16x128.bf8.bf8 (IntrinsicsAMDGPU.td:3630)
    amdgcn_smfmac_f32_16x16x128_bf8_fp8,       // llvm.amdgcn.smfmac.f32.16x16x128.bf8.fp8 (IntrinsicsAMDGPU.td:3631)
    amdgcn_smfmac_f32_16x16x128_fp8_bf8,       // llvm.amdgcn.smfmac.f32.16x16x128.fp8.bf8 (IntrinsicsAMDGPU.td:3632)
    amdgcn_smfmac_f32_16x16x128_fp8_fp8,       // llvm.amdgcn.smfmac.f32.16x16x128.fp8.fp8 (IntrinsicsAMDGPU.td:3633)
    amdgcn_smfmac_f32_16x16x32_bf16,           // llvm.amdgcn.smfmac.f32.16x16x32.bf16 (IntrinsicsAMDGPU.td:3527)
    amdgcn_smfmac_f32_16x16x32_f16,            // llvm.amdgcn.smfmac.f32.16x16x32.f16 (IntrinsicsAMDGPU.td:3525)
    amdgcn_smfmac_f32_16x16x64_bf16,           // llvm.amdgcn.smfmac.f32.16x16x64.bf16 (IntrinsicsAMDGPU.td:3626)
    amdgcn_smfmac_f32_16x16x64_bf8_bf8,        // llvm.amdgcn.smfmac.f32.16x16x64.bf8.bf8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_16x16x64_bf8_fp8,        // llvm.amdgcn.smfmac.f32.16x16x64.bf8.fp8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_16x16x64_f16,            // llvm.amdgcn.smfmac.f32.16x16x64.f16 (IntrinsicsAMDGPU.td:3624)
    amdgcn_smfmac_f32_16x16x64_fp8_bf8,        // llvm.amdgcn.smfmac.f32.16x16x64.fp8.bf8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_16x16x64_fp8_fp8,        // llvm.amdgcn.smfmac.f32.16x16x64.fp8.fp8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_32x32x16_bf16,           // llvm.amdgcn.smfmac.f32.32x32x16.bf16 (IntrinsicsAMDGPU.td:3528)
    amdgcn_smfmac_f32_32x32x16_f16,            // llvm.amdgcn.smfmac.f32.32x32x16.f16 (IntrinsicsAMDGPU.td:3526)
    amdgcn_smfmac_f32_32x32x32_bf16,           // llvm.amdgcn.smfmac.f32.32x32x32.bf16 (IntrinsicsAMDGPU.td:3627)
    amdgcn_smfmac_f32_32x32x32_bf8_bf8,        // llvm.amdgcn.smfmac.f32.32x32x32.bf8.bf8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_32x32x32_bf8_fp8,        // llvm.amdgcn.smfmac.f32.32x32x32.bf8.fp8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_32x32x32_f16,            // llvm.amdgcn.smfmac.f32.32x32x32.f16 (IntrinsicsAMDGPU.td:3625)
    amdgcn_smfmac_f32_32x32x32_fp8_bf8,        // llvm.amdgcn.smfmac.f32.32x32x32.fp8.bf8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_32x32x32_fp8_fp8,        // llvm.amdgcn.smfmac.f32.32x32x32.fp8.fp8 (IntrinsicsAMDGPU.td:3513)
    amdgcn_smfmac_f32_32x32x64_bf8_bf8,        // llvm.amdgcn.smfmac.f32.32x32x64.bf8.bf8 (IntrinsicsAMDGPU.td:3634)
    amdgcn_smfmac_f32_32x32x64_bf8_fp8,        // llvm.amdgcn.smfmac.f32.32x32x64.bf8.fp8 (IntrinsicsAMDGPU.td:3635)
    amdgcn_smfmac_f32_32x32x64_fp8_bf8,        // llvm.amdgcn.smfmac.f32.32x32x64.fp8.bf8 (IntrinsicsAMDGPU.td:3636)
    amdgcn_smfmac_f32_32x32x64_fp8_fp8,        // llvm.amdgcn.smfmac.f32.32x32x64.fp8.fp8 (IntrinsicsAMDGPU.td:3637)
    amdgcn_smfmac_i32_16x16x128_i8,            // llvm.amdgcn.smfmac.i32.16x16x128.i8 (IntrinsicsAMDGPU.td:3628)
    amdgcn_smfmac_i32_16x16x64_i8,             // llvm.amdgcn.smfmac.i32.16x16x64.i8 (IntrinsicsAMDGPU.td:3529)
    amdgcn_smfmac_i32_32x32x32_i8,             // llvm.amdgcn.smfmac.i32.32x32x32.i8 (IntrinsicsAMDGPU.td:3530)
    amdgcn_smfmac_i32_32x32x64_i8,             // llvm.amdgcn.smfmac.i32.32x32x64.i8 (IntrinsicsAMDGPU.td:3629)
    amdgcn_softwqm,                            // llvm.amdgcn.softwqm (IntrinsicsAMDGPU.td:2577)
    amdgcn_sqrt,                               // llvm.amdgcn.sqrt (IntrinsicsAMDGPU.td:474)
    amdgcn_strict_wqm,                         // llvm.amdgcn.strict.wqm (IntrinsicsAMDGPU.td:2615)
    amdgcn_strict_wwm,                         // llvm.amdgcn.strict.wwm (IntrinsicsAMDGPU.td:2606)
    amdgcn_struct_atomic_buffer_load,          // llvm.amdgcn.struct.atomic.buffer.load (IntrinsicsAMDGPU.td:1555)
    amdgcn_struct_buffer_atomic_add,           // llvm.amdgcn.struct.buffer.atomic.add (IntrinsicsAMDGPU.td:1762)
    amdgcn_struct_buffer_atomic_and,           // llvm.amdgcn.struct.buffer.atomic.and (IntrinsicsAMDGPU.td:1768)
    amdgcn_struct_buffer_atomic_cmpswap,       // llvm.amdgcn.struct.buffer.atomic.cmpswap (IntrinsicsAMDGPU.td:1775)
    amdgcn_struct_buffer_atomic_cond_sub_u32,  // llvm.amdgcn.struct.buffer.atomic.cond.sub.u32 (IntrinsicsAMDGPU.td:1773)
    amdgcn_struct_buffer_atomic_dec,           // llvm.amdgcn.struct.buffer.atomic.dec (IntrinsicsAMDGPU.td:1772)
    amdgcn_struct_buffer_atomic_fadd,          // llvm.amdgcn.struct.buffer.atomic.fadd (IntrinsicsAMDGPU.td:1826)
    amdgcn_struct_buffer_atomic_fmax,          // llvm.amdgcn.struct.buffer.atomic.fmax (IntrinsicsAMDGPU.td:1831)
    amdgcn_struct_buffer_atomic_fmin,          // llvm.amdgcn.struct.buffer.atomic.fmin (IntrinsicsAMDGPU.td:1830)
    amdgcn_struct_buffer_atomic_inc,           // llvm.amdgcn.struct.buffer.atomic.inc (IntrinsicsAMDGPU.td:1771)
    amdgcn_struct_buffer_atomic_or,            // llvm.amdgcn.struct.buffer.atomic.or (IntrinsicsAMDGPU.td:1769)
    amdgcn_struct_buffer_atomic_smax,          // llvm.amdgcn.struct.buffer.atomic.smax (IntrinsicsAMDGPU.td:1766)
    amdgcn_struct_buffer_atomic_smin,          // llvm.amdgcn.struct.buffer.atomic.smin (IntrinsicsAMDGPU.td:1764)
    amdgcn_struct_buffer_atomic_sub,           // llvm.amdgcn.struct.buffer.atomic.sub (IntrinsicsAMDGPU.td:1763)
    amdgcn_struct_buffer_atomic_sub_clamp_u32,  // llvm.amdgcn.struct.buffer.atomic.sub.clamp.u32 (IntrinsicsAMDGPU.td:1774)
    amdgcn_struct_buffer_atomic_swap,          // llvm.amdgcn.struct.buffer.atomic.swap (IntrinsicsAMDGPU.td:1761)
    amdgcn_struct_buffer_atomic_umax,          // llvm.amdgcn.struct.buffer.atomic.umax (IntrinsicsAMDGPU.td:1767)
    amdgcn_struct_buffer_atomic_umin,          // llvm.amdgcn.struct.buffer.atomic.umin (IntrinsicsAMDGPU.td:1765)
    amdgcn_struct_buffer_atomic_xor,           // llvm.amdgcn.struct.buffer.atomic.xor (IntrinsicsAMDGPU.td:1770)
    amdgcn_struct_buffer_load,                 // llvm.amdgcn.struct.buffer.load (IntrinsicsAMDGPU.td:1538)
    amdgcn_struct_buffer_load_format,          // llvm.amdgcn.struct.buffer.load.format (IntrinsicsAMDGPU.td:1537)
    amdgcn_struct_buffer_load_lds,             // llvm.amdgcn.struct.buffer.load.lds (IntrinsicsAMDGPU.td:2044)
    amdgcn_struct_buffer_store,                // llvm.amdgcn.struct.buffer.store (IntrinsicsAMDGPU.td:1648)
    amdgcn_struct_buffer_store_format,         // llvm.amdgcn.struct.buffer.store.format (IntrinsicsAMDGPU.td:1647)
    amdgcn_struct_ptr_atomic_buffer_load,      // llvm.amdgcn.struct.ptr.atomic.buffer.load (IntrinsicsAMDGPU.td:1592)
    amdgcn_struct_ptr_buffer_atomic_add,       // llvm.amdgcn.struct.ptr.buffer.atomic.add (IntrinsicsAMDGPU.td:1799)
    amdgcn_struct_ptr_buffer_atomic_and,       // llvm.amdgcn.struct.ptr.buffer.atomic.and (IntrinsicsAMDGPU.td:1805)
    amdgcn_struct_ptr_buffer_atomic_cmpswap,   // llvm.amdgcn.struct.ptr.buffer.atomic.cmpswap (IntrinsicsAMDGPU.td:1812)
    amdgcn_struct_ptr_buffer_atomic_cond_sub_u32,  // llvm.amdgcn.struct.ptr.buffer.atomic.cond.sub.u32 (IntrinsicsAMDGPU.td:1810)
    amdgcn_struct_ptr_buffer_atomic_dec,       // llvm.amdgcn.struct.ptr.buffer.atomic.dec (IntrinsicsAMDGPU.td:1809)
    amdgcn_struct_ptr_buffer_atomic_fadd,      // llvm.amdgcn.struct.ptr.buffer.atomic.fadd (IntrinsicsAMDGPU.td:1827)
    amdgcn_struct_ptr_buffer_atomic_fmax,      // llvm.amdgcn.struct.ptr.buffer.atomic.fmax (IntrinsicsAMDGPU.td:1834)
    amdgcn_struct_ptr_buffer_atomic_fmin,      // llvm.amdgcn.struct.ptr.buffer.atomic.fmin (IntrinsicsAMDGPU.td:1833)
    amdgcn_struct_ptr_buffer_atomic_inc,       // llvm.amdgcn.struct.ptr.buffer.atomic.inc (IntrinsicsAMDGPU.td:1808)
    amdgcn_struct_ptr_buffer_atomic_or,        // llvm.amdgcn.struct.ptr.buffer.atomic.or (IntrinsicsAMDGPU.td:1806)
    amdgcn_struct_ptr_buffer_atomic_smax,      // llvm.amdgcn.struct.ptr.buffer.atomic.smax (IntrinsicsAMDGPU.td:1803)
    amdgcn_struct_ptr_buffer_atomic_smin,      // llvm.amdgcn.struct.ptr.buffer.atomic.smin (IntrinsicsAMDGPU.td:1801)
    amdgcn_struct_ptr_buffer_atomic_sub,       // llvm.amdgcn.struct.ptr.buffer.atomic.sub (IntrinsicsAMDGPU.td:1800)
    amdgcn_struct_ptr_buffer_atomic_sub_clamp_u32,  // llvm.amdgcn.struct.ptr.buffer.atomic.sub.clamp.u32 (IntrinsicsAMDGPU.td:1811)
    amdgcn_struct_ptr_buffer_atomic_swap,      // llvm.amdgcn.struct.ptr.buffer.atomic.swap (IntrinsicsAMDGPU.td:1798)
    amdgcn_struct_ptr_buffer_atomic_umax,      // llvm.amdgcn.struct.ptr.buffer.atomic.umax (IntrinsicsAMDGPU.td:1804)
    amdgcn_struct_ptr_buffer_atomic_umin,      // llvm.amdgcn.struct.ptr.buffer.atomic.umin (IntrinsicsAMDGPU.td:1802)
    amdgcn_struct_ptr_buffer_atomic_xor,       // llvm.amdgcn.struct.ptr.buffer.atomic.xor (IntrinsicsAMDGPU.td:1807)
    amdgcn_struct_ptr_buffer_load,             // llvm.amdgcn.struct.ptr.buffer.load (IntrinsicsAMDGPU.td:1574)
    amdgcn_struct_ptr_buffer_load_format,      // llvm.amdgcn.struct.ptr.buffer.load.format (IntrinsicsAMDGPU.td:1573)
    amdgcn_struct_ptr_buffer_load_lds,         // llvm.amdgcn.struct.ptr.buffer.load.lds (IntrinsicsAMDGPU.td:2069)
    amdgcn_struct_ptr_buffer_store,            // llvm.amdgcn.struct.ptr.buffer.store (IntrinsicsAMDGPU.td:1668)
    amdgcn_struct_ptr_buffer_store_format,     // llvm.amdgcn.struct.ptr.buffer.store.format (IntrinsicsAMDGPU.td:1667)
    amdgcn_struct_ptr_tbuffer_load,            // llvm.amdgcn.struct.ptr.tbuffer.load (IntrinsicsAMDGPU.td:1927)
    amdgcn_struct_ptr_tbuffer_store,           // llvm.amdgcn.struct.ptr.tbuffer.store (IntrinsicsAMDGPU.td:1945)
    amdgcn_struct_tbuffer_load,                // llvm.amdgcn.struct.tbuffer.load (IntrinsicsAMDGPU.td:1909)
    amdgcn_struct_tbuffer_store,               // llvm.amdgcn.struct.tbuffer.store (IntrinsicsAMDGPU.td:1964)
    amdgcn_sudot4,                             // llvm.amdgcn.sudot4 (IntrinsicsAMDGPU.td:3320)
    amdgcn_sudot8,                             // llvm.amdgcn.sudot8 (IntrinsicsAMDGPU.td:3373)
    amdgcn_swmmac_bf16_16x16x32_bf16,          // llvm.amdgcn.swmmac.bf16.16x16x32.bf16 (IntrinsicsAMDGPU.td:3095)
    amdgcn_swmmac_bf16_16x16x64_bf16,          // llvm.amdgcn.swmmac.bf16.16x16x64.bf16 (IntrinsicsAMDGPU.td:4141)
    amdgcn_swmmac_bf16f32_16x16x64_bf16,       // llvm.amdgcn.swmmac.bf16f32.16x16x64.bf16 (IntrinsicsAMDGPU.td:4142)
    amdgcn_swmmac_f16_16x16x128_bf8_bf8,       // llvm.amdgcn.swmmac.f16.16x16x128.bf8.bf8 (IntrinsicsAMDGPU.td:4150)
    amdgcn_swmmac_f16_16x16x128_bf8_fp8,       // llvm.amdgcn.swmmac.f16.16x16x128.bf8.fp8 (IntrinsicsAMDGPU.td:4149)
    amdgcn_swmmac_f16_16x16x128_fp8_bf8,       // llvm.amdgcn.swmmac.f16.16x16x128.fp8.bf8 (IntrinsicsAMDGPU.td:4148)
    amdgcn_swmmac_f16_16x16x128_fp8_fp8,       // llvm.amdgcn.swmmac.f16.16x16x128.fp8.fp8 (IntrinsicsAMDGPU.td:4147)
    amdgcn_swmmac_f16_16x16x32_f16,            // llvm.amdgcn.swmmac.f16.16x16x32.f16 (IntrinsicsAMDGPU.td:3094)
    amdgcn_swmmac_f16_16x16x64_f16,            // llvm.amdgcn.swmmac.f16.16x16x64.f16 (IntrinsicsAMDGPU.td:4140)
    amdgcn_swmmac_f32_16x16x128_bf8_bf8,       // llvm.amdgcn.swmmac.f32.16x16x128.bf8.bf8 (IntrinsicsAMDGPU.td:4146)
    amdgcn_swmmac_f32_16x16x128_bf8_fp8,       // llvm.amdgcn.swmmac.f32.16x16x128.bf8.fp8 (IntrinsicsAMDGPU.td:4145)
    amdgcn_swmmac_f32_16x16x128_fp8_bf8,       // llvm.amdgcn.swmmac.f32.16x16x128.fp8.bf8 (IntrinsicsAMDGPU.td:4144)
    amdgcn_swmmac_f32_16x16x128_fp8_fp8,       // llvm.amdgcn.swmmac.f32.16x16x128.fp8.fp8 (IntrinsicsAMDGPU.td:4143)
    amdgcn_swmmac_f32_16x16x32_bf16,           // llvm.amdgcn.swmmac.f32.16x16x32.bf16 (IntrinsicsAMDGPU.td:3093)
    amdgcn_swmmac_f32_16x16x32_bf8_bf8,        // llvm.amdgcn.swmmac.f32.16x16x32.bf8.bf8 (IntrinsicsAMDGPU.td:3102)
    amdgcn_swmmac_f32_16x16x32_bf8_fp8,        // llvm.amdgcn.swmmac.f32.16x16x32.bf8.fp8 (IntrinsicsAMDGPU.td:3101)
    amdgcn_swmmac_f32_16x16x32_f16,            // llvm.amdgcn.swmmac.f32.16x16x32.f16 (IntrinsicsAMDGPU.td:3092)
    amdgcn_swmmac_f32_16x16x32_fp8_bf8,        // llvm.amdgcn.swmmac.f32.16x16x32.fp8.bf8 (IntrinsicsAMDGPU.td:3100)
    amdgcn_swmmac_f32_16x16x32_fp8_fp8,        // llvm.amdgcn.swmmac.f32.16x16x32.fp8.fp8 (IntrinsicsAMDGPU.td:3099)
    amdgcn_swmmac_f32_16x16x64_bf16,           // llvm.amdgcn.swmmac.f32.16x16x64.bf16 (IntrinsicsAMDGPU.td:4139)
    amdgcn_swmmac_f32_16x16x64_f16,            // llvm.amdgcn.swmmac.f32.16x16x64.f16 (IntrinsicsAMDGPU.td:4138)
    amdgcn_swmmac_i32_16x16x128_iu8,           // llvm.amdgcn.swmmac.i32.16x16x128.iu8 (IntrinsicsAMDGPU.td:4151)
    amdgcn_swmmac_i32_16x16x32_iu4,            // llvm.amdgcn.swmmac.i32.16x16x32.iu4 (IntrinsicsAMDGPU.td:3097)
    amdgcn_swmmac_i32_16x16x32_iu8,            // llvm.amdgcn.swmmac.i32.16x16x32.iu8 (IntrinsicsAMDGPU.td:3096)
    amdgcn_swmmac_i32_16x16x64_iu4,            // llvm.amdgcn.swmmac.i32.16x16x64.iu4 (IntrinsicsAMDGPU.td:3098)
    amdgcn_tanh,                               // llvm.amdgcn.tanh (IntrinsicsAMDGPU.td:572)
    amdgcn_tensor_load_to_lds,                 // llvm.amdgcn.tensor.load.to.lds (IntrinsicsAMDGPU.td:4181)
    amdgcn_tensor_load_to_lds_d2,              // llvm.amdgcn.tensor.load.to.lds.d2 (IntrinsicsAMDGPU.td:4185)
    amdgcn_tensor_store_from_lds,              // llvm.amdgcn.tensor.store.from.lds (IntrinsicsAMDGPU.td:4183)
    amdgcn_tensor_store_from_lds_d2,           // llvm.amdgcn.tensor.store.from.lds.d2 (IntrinsicsAMDGPU.td:4187)
    amdgcn_trig_preop,                         // llvm.amdgcn.trig.preop (IntrinsicsAMDGPU.td:418)
    amdgcn_ubfe,                               // llvm.amdgcn.ubfe (IntrinsicsAMDGPU.td:2361)
    amdgcn_udot2,                              // llvm.amdgcn.udot2 (IntrinsicsAMDGPU.td:3272)
    amdgcn_udot4,                              // llvm.amdgcn.udot4 (IntrinsicsAMDGPU.td:3302)
    amdgcn_udot8,                              // llvm.amdgcn.udot8 (IntrinsicsAMDGPU.td:3354)
    amdgcn_unreachable,                        // llvm.amdgcn.unreachable (IntrinsicsAMDGPU.td:3839)
    amdgcn_update_dpp,                         // llvm.amdgcn.update.dpp (IntrinsicsAMDGPU.td:2734)
    amdgcn_wave_barrier,                       // llvm.amdgcn.wave.barrier (IntrinsicsAMDGPU.td:346)
    amdgcn_wave_id,                            // llvm.amdgcn.wave.id (IntrinsicsAMDGPU.td:3142)
    amdgcn_wave_reduce_add,                    // llvm.amdgcn.wave.reduce.add (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_and,                    // llvm.amdgcn.wave.reduce.and (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_fadd,                   // llvm.amdgcn.wave.reduce.fadd (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_fmax,                   // llvm.amdgcn.wave.reduce.fmax (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_fmin,                   // llvm.amdgcn.wave.reduce.fmin (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_fsub,                   // llvm.amdgcn.wave.reduce.fsub (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_max,                    // llvm.amdgcn.wave.reduce.max (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_min,                    // llvm.amdgcn.wave.reduce.min (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_or,                     // llvm.amdgcn.wave.reduce.or (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_sub,                    // llvm.amdgcn.wave.reduce.sub (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_umax,                   // llvm.amdgcn.wave.reduce.umax (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_umin,                   // llvm.amdgcn.wave.reduce.umin (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_reduce_xor,                    // llvm.amdgcn.wave.reduce.xor (IntrinsicsAMDGPU.td:2456)
    amdgcn_wave_shuffle,                       // llvm.amdgcn.wave.shuffle (IntrinsicsAMDGPU.td:2692)
    amdgcn_wavefrontsize,                      // llvm.amdgcn.wavefrontsize (IntrinsicsAMDGPU.td:250)
    amdgcn_wmma_bf16_16x16x16_bf16,            // llvm.amdgcn.wmma.bf16.16x16x16.bf16 (IntrinsicsAMDGPU.td:2978)
    amdgcn_wmma_bf16_16x16x16_bf16_tied,       // llvm.amdgcn.wmma.bf16.16x16x16.bf16.tied (IntrinsicsAMDGPU.td:2965)
    amdgcn_wmma_bf16_16x16x32_bf16,            // llvm.amdgcn.wmma.bf16.16x16x32.bf16 (IntrinsicsAMDGPU.td:4075)
    amdgcn_wmma_bf16f32_16x16x32_bf16,         // llvm.amdgcn.wmma.bf16f32.16x16x32.bf16 (IntrinsicsAMDGPU.td:4076)
    amdgcn_wmma_f16_16x16x128_bf8_bf8,         // llvm.amdgcn.wmma.f16.16x16x128.bf8.bf8 (IntrinsicsAMDGPU.td:4088)
    amdgcn_wmma_f16_16x16x128_bf8_fp8,         // llvm.amdgcn.wmma.f16.16x16x128.bf8.fp8 (IntrinsicsAMDGPU.td:4087)
    amdgcn_wmma_f16_16x16x128_fp8_bf8,         // llvm.amdgcn.wmma.f16.16x16x128.fp8.bf8 (IntrinsicsAMDGPU.td:4086)
    amdgcn_wmma_f16_16x16x128_fp8_fp8,         // llvm.amdgcn.wmma.f16.16x16x128.fp8.fp8 (IntrinsicsAMDGPU.td:4085)
    amdgcn_wmma_f16_16x16x16_f16,              // llvm.amdgcn.wmma.f16.16x16x16.f16 (IntrinsicsAMDGPU.td:2977)
    amdgcn_wmma_f16_16x16x16_f16_tied,         // llvm.amdgcn.wmma.f16.16x16x16.f16.tied (IntrinsicsAMDGPU.td:2964)
    amdgcn_wmma_f16_16x16x32_f16,              // llvm.amdgcn.wmma.f16.16x16x32.f16 (IntrinsicsAMDGPU.td:4074)
    amdgcn_wmma_f16_16x16x64_bf8_bf8,          // llvm.amdgcn.wmma.f16.16x16x64.bf8.bf8 (IntrinsicsAMDGPU.td:4084)
    amdgcn_wmma_f16_16x16x64_bf8_fp8,          // llvm.amdgcn.wmma.f16.16x16x64.bf8.fp8 (IntrinsicsAMDGPU.td:4083)
    amdgcn_wmma_f16_16x16x64_fp8_bf8,          // llvm.amdgcn.wmma.f16.16x16x64.fp8.bf8 (IntrinsicsAMDGPU.td:4082)
    amdgcn_wmma_f16_16x16x64_fp8_fp8,          // llvm.amdgcn.wmma.f16.16x16x64.fp8.fp8 (IntrinsicsAMDGPU.td:4081)
    amdgcn_wmma_f32_16x16x128_bf8_bf8,         // llvm.amdgcn.wmma.f32.16x16x128.bf8.bf8 (IntrinsicsAMDGPU.td:4092)
    amdgcn_wmma_f32_16x16x128_bf8_fp8,         // llvm.amdgcn.wmma.f32.16x16x128.bf8.fp8 (IntrinsicsAMDGPU.td:4091)
    amdgcn_wmma_f32_16x16x128_f8f6f4,          // llvm.amdgcn.wmma.f32.16x16x128.f8f6f4 (IntrinsicsAMDGPU.td:4094)
    amdgcn_wmma_f32_16x16x128_fp8_bf8,         // llvm.amdgcn.wmma.f32.16x16x128.fp8.bf8 (IntrinsicsAMDGPU.td:4090)
    amdgcn_wmma_f32_16x16x128_fp8_fp8,         // llvm.amdgcn.wmma.f32.16x16x128.fp8.fp8 (IntrinsicsAMDGPU.td:4089)
    amdgcn_wmma_f32_16x16x16_bf16,             // llvm.amdgcn.wmma.f32.16x16x16.bf16 (IntrinsicsAMDGPU.td:2970)
    amdgcn_wmma_f32_16x16x16_bf8_bf8,          // llvm.amdgcn.wmma.f32.16x16x16.bf8.bf8 (IntrinsicsAMDGPU.td:3088)
    amdgcn_wmma_f32_16x16x16_bf8_fp8,          // llvm.amdgcn.wmma.f32.16x16x16.bf8.fp8 (IntrinsicsAMDGPU.td:3087)
    amdgcn_wmma_f32_16x16x16_f16,              // llvm.amdgcn.wmma.f32.16x16x16.f16 (IntrinsicsAMDGPU.td:2969)
    amdgcn_wmma_f32_16x16x16_fp8_bf8,          // llvm.amdgcn.wmma.f32.16x16x16.fp8.bf8 (IntrinsicsAMDGPU.td:3086)
    amdgcn_wmma_f32_16x16x16_fp8_fp8,          // llvm.amdgcn.wmma.f32.16x16x16.fp8.fp8 (IntrinsicsAMDGPU.td:3085)
    amdgcn_wmma_f32_16x16x32_bf16,             // llvm.amdgcn.wmma.f32.16x16x32.bf16 (IntrinsicsAMDGPU.td:4072)
    amdgcn_wmma_f32_16x16x32_f16,              // llvm.amdgcn.wmma.f32.16x16x32.f16 (IntrinsicsAMDGPU.td:4073)
    amdgcn_wmma_f32_16x16x4_f32,               // llvm.amdgcn.wmma.f32.16x16x4.f32 (IntrinsicsAMDGPU.td:4071)
    amdgcn_wmma_f32_16x16x64_bf8_bf8,          // llvm.amdgcn.wmma.f32.16x16x64.bf8.bf8 (IntrinsicsAMDGPU.td:4080)
    amdgcn_wmma_f32_16x16x64_bf8_fp8,          // llvm.amdgcn.wmma.f32.16x16x64.bf8.fp8 (IntrinsicsAMDGPU.td:4079)
    amdgcn_wmma_f32_16x16x64_fp8_bf8,          // llvm.amdgcn.wmma.f32.16x16x64.fp8.bf8 (IntrinsicsAMDGPU.td:4078)
    amdgcn_wmma_f32_16x16x64_fp8_fp8,          // llvm.amdgcn.wmma.f32.16x16x64.fp8.fp8 (IntrinsicsAMDGPU.td:4077)
    amdgcn_wmma_f32_32x16x128_f4,              // llvm.amdgcn.wmma.f32.32x16x128.f4 (IntrinsicsAMDGPU.td:4097)
    amdgcn_wmma_i32_16x16x16_iu4,              // llvm.amdgcn.wmma.i32.16x16x16.iu4 (IntrinsicsAMDGPU.td:2972)
    amdgcn_wmma_i32_16x16x16_iu8,              // llvm.amdgcn.wmma.i32.16x16x16.iu8 (IntrinsicsAMDGPU.td:2971)
    amdgcn_wmma_i32_16x16x32_iu4,              // llvm.amdgcn.wmma.i32.16x16x32.iu4 (IntrinsicsAMDGPU.td:3090)
    amdgcn_wmma_i32_16x16x64_iu8,              // llvm.amdgcn.wmma.i32.16x16x64.iu8 (IntrinsicsAMDGPU.td:4093)
    amdgcn_wmma_scale_f32_16x16x128_f8f6f4,    // llvm.amdgcn.wmma.scale.f32.16x16x128.f8f6f4 (IntrinsicsAMDGPU.td:4095)
    amdgcn_wmma_scale_f32_32x16x128_f4,        // llvm.amdgcn.wmma.scale.f32.32x16x128.f4 (IntrinsicsAMDGPU.td:4098)
    amdgcn_wmma_scale16_f32_16x16x128_f8f6f4,  // llvm.amdgcn.wmma.scale16.f32.16x16x128.f8f6f4 (IntrinsicsAMDGPU.td:4096)
    amdgcn_wmma_scale16_f32_32x16x128_f4,      // llvm.amdgcn.wmma.scale16.f32.32x16x128.f4 (IntrinsicsAMDGPU.td:4099)
    amdgcn_workgroup_id_x,                     // llvm.amdgcn.workgroup.id.x (IntrinsicsAMDGPU.td:53)
    amdgcn_workgroup_id_y,                     // llvm.amdgcn.workgroup.id.y (IntrinsicsAMDGPU.td:55)
    amdgcn_workgroup_id_z,                     // llvm.amdgcn.workgroup.id.z (IntrinsicsAMDGPU.td:57)
    amdgcn_workitem_id_x,                      // llvm.amdgcn.workitem.id.x (IntrinsicsAMDGPU.td:53)
    amdgcn_workitem_id_y,                      // llvm.amdgcn.workitem.id.y (IntrinsicsAMDGPU.td:55)
    amdgcn_workitem_id_z,                      // llvm.amdgcn.workitem.id.z (IntrinsicsAMDGPU.td:57)
    amdgcn_wqm,                                // llvm.amdgcn.wqm (IntrinsicsAMDGPU.td:2570)
    amdgcn_wqm_demote,                         // llvm.amdgcn.wqm.demote (IntrinsicsAMDGPU.td:2597)
    amdgcn_wqm_vote,                           // llvm.amdgcn.wqm.vote (IntrinsicsAMDGPU.td:2583)
    amdgcn_writelane,                          // llvm.amdgcn.writelane (IntrinsicsAMDGPU.td:2475)
    amdgcn_wwm,                                // llvm.amdgcn.wwm (IntrinsicsAMDGPU.td:2611)
}; // enum
} // namespace llvm::Intrinsic
#endif

